![Voucherify Ruby SDK](./voucherify-ruby-sdk.png)

## Official [Voucherify](https://voucherify.io?utm_source=github&utm_medium=sdk&utm_campaign=acq) SDK for Ruby

[![Gem Version](https://img.shields.io/gem/v/voucherify.svg)](https://rubygems.org/gems/voucherify)
[![Gem Downloads](https://img.shields.io/gem/dt/voucherify.svg)](https://rubygems.org/gems/voucherify)
[![License](https://img.shields.io/github/license/voucherifyio/sdk-ruby-openapi-based.svg)](https://opensource.org/licenses/MIT)
[![GitHub issues](https://img.shields.io/github/issues/voucherifyio/sdk-ruby-openapi-based.svg)](https://github.com/voucherifyio/sdk-ruby-openapi-based/issues)

Voucherify empowers marketers and developers with flexible building blocks to come up with, implement, and track targeted promotional campaigns.

Learn more about Voucherify by visiting [our site](https://www.voucherify.io).

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) based on our [Documentation](https://docs.voucherify.io/docs/introduction) with v2018-08-01 version.

The legacy version of Ruby SDK could be found [here](https://github.com/voucherifyio/voucherify-ruby-sdk)

## 📝 Documentation

You will find detailed description and example responses at our [official documentation](https://docs.voucherify.io/reference). Most method headers point to more detailed descriptions of arguments you can use.

📚 Want to learn more? Visit our [official site](https://www.voucherify.io) or our [Success Portal](https://success.voucherify.io).

👽 Having troubles? Check our [Help center](https://support.voucherify.io/).

🧪 Looking for promotion ideas? Check our [Cookbook](https://cookbook.voucherify.io/) to get an inspiration.

🐛 Encounter a bug? Please file a report in the [Issues](https://github.com/voucherifyio/sdk-ruby-openapi-based/issues).

## ⚙️ Installation

### Gem Repository

The SDK is hosted in [RubeGems](https://rubygems.org/gems/voucherify) and could be easy obtained by adding this line to Your application's Gemfile:

```ruby
gem 'voucherify'
```

And then execute:

```shell
bundle install
```

Or install it yourself as:

```shell
gem install voucherify
```

### 🚀 Running code

When You have Voucherify gem installed You could use pre-created [example.rb](./example.rb) with example code for testing purpose.

```ruby example.rb
# Load the gem
require 'VoucherifySdk'

# Setup authorization
VoucherifySdk.configure do |config|
    # Configure API key authorization: X-App-Id
    config.api_key['X-App-Id'] = 'YOUR API KEY'

    # Configure API key authorization: X-App-Token
    config.api_key['X-App-Token'] = 'YOUR API KEY'

    # (Optional) Configure Voucherify cluster, default is https://api.voucherify.io
    # config.host = 'https://us1.api.voucherify.io'
end

# Creating API Instance
api_instance = VoucherifySdk::CampaignsApi.new

# Calling list_campaigns
begin
    result = api_instance.list_campaigns()
    puts result
rescue VoucherifySdk::ApiError => e
    puts "Exception when calling VouchersApi->list_campaigns: #{e}"
end
```

Code could be run from the directory where the file is placed (root for this repository), by using:

```shell
ruby example.rb
```

Or, if You're using bundler:

```shell
bundle exec ruby example.rb
```

🛡️ This code does simple campaign list, so it won't affect Your Voucherify data.

🔒 Remember to fill Your Voucherify keys for the valid authorization.

💅 More examples and good practices You could find in the [EXAMPLES.md](./EXAMPLES.md) document.

## 🐳 Running local tests with docker

1. Copy `.env.example` to `.env` and fill in the values.
2. Run `docker build -t ruby .` to build the image.
3. Run `docker run --rm ruby` to run the tests and delete container immediately after.

## 🛠️ Contributing

Read more about how to Contribute to Voucherify Ruby SDK by visiting main repo [GENERATING-SDKS.md](https://github.com/voucherifyio/voucherify-openapi/blob/master/GENERATING-SDKS.md)

Remember that this SDK is auto generated (except of the tests) so changes made here will be overwritten by generator.

## 📅 Changelog

- **2024-11-04** - `8.0.1`
  - Added support for returning `campaign_id` and `campaign_name` in stackable validation endpoint, when `redeemable` option is expanded
- **2024-10-28** - `8.0.0`
  - Added missing `enums` in few filters models
  - !!! BREAKING CHANGES !!!
    - VouchersApi.generateRandomCode now requires `VouchersCreateResponseBody` instead of plain `object`
    - property `product` in model `Discount` now uses `DiscountProduct` instead of `SimpleProductDiscountUnit`
    - property `filters` of model `ExportsCreateRequestBodyParameters` now uses plain `object` instead of `ExportsCreateRequestBodyParametersFilters`
- **2024-10-25** - `7.0.0`
  - Fix object parsing in query. For example `filters` while listing redemptions.
  - !!! BREAKING CHANGES !!!
    - Remove support for `/v1/customers/{customerId}/consents` - put `Update Customer's consents [Deprecated]`
    - Remove support for `/v1/consents` - get `List Consents [Deprecated]`
    - Remove support for `/client/v1/customers/{customerId}/consents` - put `Update Customer's consents (client-side) [Deprecated]`
    - Pagination changed on listing card transactions(listLoyaltyCardTransactions) - NO `page` param is supported - use `starting_after_id` instead.
    - Pagination changed on listing voucher transactions(listVoucherTransactions) - NO `page` param is supported - use `starting_after_id` instead.
    - ApplicableToEffect - changed - `EVERY` -> `TO_EVERY`, `CHEAPEST` -> `TO_CHEAPEST`, `MOST_EXPENSIVE` -> `TO_MOST_EXPENSIVE`, 2 new values introduced.
    - `listPublications` parameter `filters` have changed - now uses `ParameterFiltersListPublications` instead of `String`
    - `ParameterFiltersListRedemptions` and `ParameterFiltersListCustomerRedeemables` have been updated
    - enum `LUCKY_DRAW`, `LUCKY_DRAW_CODE`, `VOUCHER_LUCKY_DRAW_CODE`, `CAMPAIGN_LUCKY_DRAW` have been deleted from everywhere and no longer supported
    - CampaignsUpdateRequestBody - properties `activityDurationAfterPublishing`, `joinOnce`, `autoJoin`, `type`, `uniqueWinners`, `uniqueWinnersPerDraw` and enum `AUTO_UPDATE` | `STATIC` have been deleted and no longer supported
    - `updateCustomersConsents` has been deleted and no longer supported
    - `FilterConditionsDateTimeConditions` model has been renamed to `FilterConditionsDateTime`
    - FilterConditionsDateTime - `conditions` has been divided on `$after`, `$before`, `$hasValue`, `$isUnknown`, `moreThan`, `lessThan` properties
    - ParamterFiltersListCustomerRedeemables - model name of `createdAt` has been renamed from `FilterConditionsDateTime` to `ParameterFiltersListCustomerRedeemablesCreatedAt`
    - `filter` property in schemas ProductCollectionsCreateRequestBody, ProductCollectionsCreateResponseBody, ProductCollectionsItem and ProductCollectionsGetResponseBody has changed. Uses plain `object`.
    - `discount` property in schema CampaignsUpdateRequestBody now uses `Discount` model
    - properties `winnersCount`, `uniqueWinnersPerDraw`, `uniqueWinners` in model `CampaignsUpdateRequestBody` were deleted.
    - property `stackingRulesType` were deleted from models `CategoriesGetResponseBody`, `Category`
    - property `categories` in model `ClientValidationsValidateResponseBodyRedeemablesItem` uses now Array<CategoryWithStackingRulesType> model
    - model `ParameterFiltersListCustomerRedeemablesCampaignId` has been fixed, can use junction properly.
    - model `ParameterFiltersListRedemptions` has been fixed, can use junction properly.
    - property `filter` in model `ProductCollectionsCreateRequestBody` now uses plain Object
    - property `categories` in model `QualificationsRedeemable` now uses `Array<CategoryWithStackingRulesType>`
  - Added support:
    - /v1/metadata-schemas - get `List Metadata Schemas`
    - /v1/metadata-schemas/{resource} - get `Get Metadata Schema`
    - /v1/locations - `List Locations`
    - /v1/locations/{locationId} - get `Get Location`
    - /v1/referrals/{campaignId}/members/{memberId}/holders - post `Add Referral Code Holders`
    - /v1/referrals/{campaignId}/members/{memberId}/holders - get `List Referral Code Holders`
    - /v1/referrals/{campaignId}/members/{memberId}/holders/{holderId} - delete `Remove Referral Card Holder`
    - /v1/referrals/members/{memberId}/holders - post `Add Referral Code Holders`
    - /v1/referrals/members/{memberId}/holders - get `List Referral Code Holders`
    - /v1/referrals/members/{memberId}/holders/{holderId} - delete `Remove Referral Card Holder`
    - /v1/trash-bin - get `List Bin Entries`
    - /v1/trash-bin/{binEntryId} - delete `Delete Bin Entry`
    - /v1/templates/campaigns - get `List Campaign Templates`
    - /v1/templates/campaigns - post `Create Campaign Template`
    - /v1/templates/campaigns/{campaignTemplateId} - get `Get Campaign Template`
    - /v1/templates/campaigns/{campaignTemplateId} - put `Update Campaign Template`
    - /v1/templates/campaigns/{campaignTemplateId} - delete `Delete Campaign Template`
    - /v1/templates/campaigns/{campaignTemplateId}/campaign-setup - post `Create Campaign From Template`
    - /v1/templates/campaigns/{campaignTemplateId}/tier-setup - post `Add Promotion Tier From Template`
    - /management/v1/projects - post `Create Project`
    - /management/v1/projects - get `List Projects`
    - /management/v1/projects/{projectId} - get `Get Project`
    - /management/v1/projects/{projectId} - put `Update Project`
    - /management/v1/projects/{projectId} - delete `Delete Project`
    - /management/v1/projects/{projectId}/users - post `Assign User`
    - /management/v1/projects/{projectId}/users/{userId} - put `Update User`
    - /management/v1/projects/{projectId}/users/{userId} - delete `Unassign User`
    - /management/v1/projects/users/invite - post `Invite a New User`
    - /management/v1/projects/{projectId}/templates/campaigns - get `List Campaign Templates`
    - /management/v1/projects/{projectId}/templates/campaigns/{campaignTemplateId}/copy - post `Copy Campaign Template to a Project`
    - /management/v1/projects/{projectId}/stacking-rules - post `Create Stacking Rules`
    - /management/v1/projects/{projectId}/stacking-rules - get `List Stacking Rules`
    - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - get `Get Stacking Rules`
    - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - put `Update Stacking Rules`
    - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - delete `Delete Stacking Rules`
    - /management/v1/projects/{projectId}/metadata-schemas - post `Create Metadata Schema`
    - /management/v1/projects/{projectId}/metadata-schemas - get `List Metadata Schemas`
    - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - get `Get Metadata Schema`
    - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - put `Update Metadata Schema`
    - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - delete `Delete Metadata Schema`
    - /management/v1/projects/{projectId}/custom-event-schemas - post `Create Custom Event Schema`
    - /management/v1/projects/{projectId}/custom-event-schemas - get `List Custom Event Schemas`
    - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - get `Get Custom Event Schema`
    - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - put `Update Custom Event Schema`
    - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - delete `Delete Custom Event Schema`
    - /management/v1/projects/{projectId}/webhooks - post `Create Webhook`
    - /management/v1/projects/{projectId}/webhooks - get `List Webhooks`
    - /management/v1/projects/{projectId}/webhooks/{webhookId} - get `Get Webhook`
    - /management/v1/projects/{projectId}/webhooks/{webhookId} - put `Update Webhook`
    - /management/v1/projects/{projectId}/webhooks/{webhookId} - delete `Delete Webhook`
    - /management/v1/projects/{projectId}/branding - post `Create Brand`
    - /management/v1/projects/{projectId}/branding - get `List Brands`
    - /management/v1/projects/{projectId}/branding/{brandingId} - get `Get Brand`
    - /management/v1/projects/{projectId}/branding/{brandingId} - put `Update Brand`
    - /management/v1/projects/{projectId}/branding/{brandingId} - delete `Delete Brand`
- **2024-09-05** - `6.0.0` - The new version of the SKD includes coverage for all the most commonly used Voucherify endpoints and supports typed models.

*Previous versions of the SDK are no longer supported, and we highly recommend upgrading to version 6.0.0, which is now designated as Long-Term Support (LTS).*

*Changelog for previous versions could be found in the [DEPRECATED_CHANGELOG.md file](./DEPRECATED_CHANGELOG.md)*

## 🔐 Documentation for Authorization

```ruby
# Setup authorization
VoucherifySdk.configure do |config|
    # Application Keys
    config.api_key['X-App-Id'] = 'YOUR API ID'
    config.api_key['X-App-Token'] = 'YOUR API TOKEN'

    # Client-side Keys
    config.api_key['X-Client-Application-Id'] = 'YOUR CLIENT API ID'
    config.api_key['X-Client-Token'] = 'YOUR CLIENT API TOKEN'

    # Cluster (Optional)
    # default is https://api.voucherify.io
    config.host = 'https://us1.api.voucherify.io'
end
```

## 🌐 Documentation for API Endpoints

All URIs are relative to *https://api.voucherify.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*VoucherifySdk::AsyncActionsApi* | [**get_async_action**](docs/AsyncActionsApi.md#get_async_action) | **GET** /v1/async-actions/{asyncActionId} | Get Async Action
*VoucherifySdk::AsyncActionsApi* | [**list_async_actions**](docs/AsyncActionsApi.md#list_async_actions) | **GET** /v1/async-actions | List Async Actions
*VoucherifySdk::BinApi* | [**delete_bin_entry**](docs/BinApi.md#delete_bin_entry) | **DELETE** /v1/trash-bin/{binEntryId} | Delete Bin Entry
*VoucherifySdk::BinApi* | [**list_bin_entries**](docs/BinApi.md#list_bin_entries) | **GET** /v1/trash-bin | List Bin Entries
*VoucherifySdk::CampaignsApi* | [**add_voucher_with_specific_code_to_campaign**](docs/CampaignsApi.md#add_voucher_with_specific_code_to_campaign) | **POST** /v1/campaigns/{campaignId}/vouchers/{code} | Add Voucher with Specific Code to Campaign
*VoucherifySdk::CampaignsApi* | [**add_vouchers_to_campaign**](docs/CampaignsApi.md#add_vouchers_to_campaign) | **POST** /v1/campaigns/{campaignId}/vouchers | Add Vouchers to Campaign
*VoucherifySdk::CampaignsApi* | [**create_campaign**](docs/CampaignsApi.md#create_campaign) | **POST** /v1/campaigns | Create Campaign
*VoucherifySdk::CampaignsApi* | [**delete_campaign**](docs/CampaignsApi.md#delete_campaign) | **DELETE** /v1/campaigns/{campaignId} | Delete Campaign
*VoucherifySdk::CampaignsApi* | [**disable_campaign**](docs/CampaignsApi.md#disable_campaign) | **POST** /v1/campaigns/{campaignId}/disable | Disable Campaign
*VoucherifySdk::CampaignsApi* | [**enable_campaign**](docs/CampaignsApi.md#enable_campaign) | **POST** /v1/campaigns/{campaignId}/enable | Enable Campaign
*VoucherifySdk::CampaignsApi* | [**get_campaign**](docs/CampaignsApi.md#get_campaign) | **GET** /v1/campaigns/{campaignId} | Get Campaign
*VoucherifySdk::CampaignsApi* | [**import_vouchers_to_campaign**](docs/CampaignsApi.md#import_vouchers_to_campaign) | **POST** /v1/campaigns/{campaignId}/import | Import Vouchers to Campaign
*VoucherifySdk::CampaignsApi* | [**import_vouchers_to_campaign_using_csv**](docs/CampaignsApi.md#import_vouchers_to_campaign_using_csv) | **POST** /v1/campaigns/{campaignId}/importCSV | Import Vouchers to Campaign by CSV
*VoucherifySdk::CampaignsApi* | [**list_campaigns**](docs/CampaignsApi.md#list_campaigns) | **GET** /v1/campaigns | List Campaigns
*VoucherifySdk::CampaignsApi* | [**update_campaign**](docs/CampaignsApi.md#update_campaign) | **PUT** /v1/campaigns/{campaignId} | Update Campaign
*VoucherifySdk::CategoriesApi* | [**create_category**](docs/CategoriesApi.md#create_category) | **POST** /v1/categories | Create Category
*VoucherifySdk::CategoriesApi* | [**delete_category**](docs/CategoriesApi.md#delete_category) | **DELETE** /v1/categories/{categoryId} | Delete Category
*VoucherifySdk::CategoriesApi* | [**get_category**](docs/CategoriesApi.md#get_category) | **GET** /v1/categories/{categoryId} | Get Category
*VoucherifySdk::CategoriesApi* | [**list_categories**](docs/CategoriesApi.md#list_categories) | **GET** /v1/categories | List Categories
*VoucherifySdk::CategoriesApi* | [**update_category**](docs/CategoriesApi.md#update_category) | **PUT** /v1/categories/{categoryId} | Update Category
*VoucherifySdk::ClientSideApi* | [**check_eligibility_client_side**](docs/ClientSideApi.md#check_eligibility_client_side) | **POST** /client/v1/qualifications | Check Eligibility (client-side)
*VoucherifySdk::ClientSideApi* | [**list_promotion_tiers_client_side**](docs/ClientSideApi.md#list_promotion_tiers_client_side) | **GET** /client/v1/promotions/tiers | List Promotion Tiers (client-side)
*VoucherifySdk::ClientSideApi* | [**redeem_stacked_discounts_client_side**](docs/ClientSideApi.md#redeem_stacked_discounts_client_side) | **POST** /client/v1/redemptions | Redeem Stackable Discounts (client-side)
*VoucherifySdk::ClientSideApi* | [**track_custom_event_client_side**](docs/ClientSideApi.md#track_custom_event_client_side) | **POST** /client/v1/events | Track Custom Event (client-side)
*VoucherifySdk::ClientSideApi* | [**validate_stacked_discounts_client_side**](docs/ClientSideApi.md#validate_stacked_discounts_client_side) | **POST** /client/v1/validations | Validate Stackable Discounts (client-side)
*VoucherifySdk::CustomersApi* | [**create_customer**](docs/CustomersApi.md#create_customer) | **POST** /v1/customers | Create Customer
*VoucherifySdk::CustomersApi* | [**customer_permanently_deletion**](docs/CustomersApi.md#customer_permanently_deletion) | **POST** /v1/customers/{customerId}/permanent-deletion | Delete Customer Permanently
*VoucherifySdk::CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /v1/customers/{customerId} | Delete Customer
*VoucherifySdk::CustomersApi* | [**get_customer**](docs/CustomersApi.md#get_customer) | **GET** /v1/customers/{customerId} | Get Customer
*VoucherifySdk::CustomersApi* | [**import_customers_using_csv**](docs/CustomersApi.md#import_customers_using_csv) | **POST** /v1/customers/importCSV | Import and Update Customers using CSV
*VoucherifySdk::CustomersApi* | [**list_customer_activities**](docs/CustomersApi.md#list_customer_activities) | **GET** /v1/customers/{customerId}/activities | List Customer Activities [Deprecated]
*VoucherifySdk::CustomersApi* | [**list_customer_activity**](docs/CustomersApi.md#list_customer_activity) | **GET** /v1/customers/{customerId}/activity | List Customer Activity
*VoucherifySdk::CustomersApi* | [**list_customer_redeemables**](docs/CustomersApi.md#list_customer_redeemables) | **GET** /v1/customers/{customerId}/redeemables | List Customer's Redeemables
*VoucherifySdk::CustomersApi* | [**list_customer_segments**](docs/CustomersApi.md#list_customer_segments) | **GET** /v1/customers/{customerId}/segments | List Customer's Segments
*VoucherifySdk::CustomersApi* | [**list_customers**](docs/CustomersApi.md#list_customers) | **GET** /v1/customers | List Customers
*VoucherifySdk::CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PUT** /v1/customers/{customerId} | Update Customer
*VoucherifySdk::CustomersApi* | [**update_customers_in_bulk**](docs/CustomersApi.md#update_customers_in_bulk) | **POST** /v1/customers/bulk/async | Update Customers in Bulk
*VoucherifySdk::CustomersApi* | [**update_customers_metadata_in_bulk**](docs/CustomersApi.md#update_customers_metadata_in_bulk) | **POST** /v1/customers/metadata/async | Update Customers' Metadata in Bulk
*VoucherifySdk::EventsApi* | [**track_custom_event**](docs/EventsApi.md#track_custom_event) | **POST** /v1/events | Track Custom Event
*VoucherifySdk::ExportsApi* | [**create_export**](docs/ExportsApi.md#create_export) | **POST** /v1/exports | Create Export
*VoucherifySdk::ExportsApi* | [**delete_export**](docs/ExportsApi.md#delete_export) | **DELETE** /v1/exports/{exportId} | Delete Export
*VoucherifySdk::ExportsApi* | [**download_export**](docs/ExportsApi.md#download_export) | **GET** /v1/exports/{export_Id} | Download Export
*VoucherifySdk::ExportsApi* | [**get_export**](docs/ExportsApi.md#get_export) | **GET** /v1/exports/{exportId} | Get Export
*VoucherifySdk::ExportsApi* | [**list_exports**](docs/ExportsApi.md#list_exports) | **GET** /v1/exports | List Exports
*VoucherifySdk::LocationsApi* | [**get_location**](docs/LocationsApi.md#get_location) | **GET** /v1/locations/{locationId} | Get Location
*VoucherifySdk::LocationsApi* | [**list_locations**](docs/LocationsApi.md#list_locations) | **GET** /v1/locations | List Locations
*VoucherifySdk::LoyaltiesApi* | [**add_member**](docs/LoyaltiesApi.md#add_member) | **POST** /v1/loyalties/{campaignId}/members | Add Member
*VoucherifySdk::LoyaltiesApi* | [**create_earning_rule**](docs/LoyaltiesApi.md#create_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules | Create Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**create_in_bulk_loyalty_tiers**](docs/LoyaltiesApi.md#create_in_bulk_loyalty_tiers) | **POST** /v1/loyalties/{campaignId}/tiers | Create loyalty tiers
*VoucherifySdk::LoyaltiesApi* | [**create_loyalty_program**](docs/LoyaltiesApi.md#create_loyalty_program) | **POST** /v1/loyalties | Create Loyalty Campaign
*VoucherifySdk::LoyaltiesApi* | [**create_points_expiration_export**](docs/LoyaltiesApi.md#create_points_expiration_export) | **POST** /v1/loyalties/{campaignId}/points-expiration/export | Create Points Expiration Export
*VoucherifySdk::LoyaltiesApi* | [**create_reward_assignment1**](docs/LoyaltiesApi.md#create_reward_assignment1) | **POST** /v1/loyalties/{campaignId}/rewards | Create Reward Assignment
*VoucherifySdk::LoyaltiesApi* | [**delete_earning_rule**](docs/LoyaltiesApi.md#delete_earning_rule) | **DELETE** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Delete Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**delete_loyalty_program**](docs/LoyaltiesApi.md#delete_loyalty_program) | **DELETE** /v1/loyalties/{campaignId} | Delete Loyalty Campaign
*VoucherifySdk::LoyaltiesApi* | [**delete_reward_assignment1**](docs/LoyaltiesApi.md#delete_reward_assignment1) | **DELETE** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Delete Reward Assignment
*VoucherifySdk::LoyaltiesApi* | [**disable_earning_rule**](docs/LoyaltiesApi.md#disable_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId}/disable | Disable Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**enable_earning_rule**](docs/LoyaltiesApi.md#enable_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId}/enable | Enable Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**export_loyalty_card_transactions**](docs/LoyaltiesApi.md#export_loyalty_card_transactions) | **POST** /v1/loyalties/members/{memberId}/transactions/export | Export Loyalty Card Transactions
*VoucherifySdk::LoyaltiesApi* | [**export_loyalty_card_transactions1**](docs/LoyaltiesApi.md#export_loyalty_card_transactions1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/transactions/export | Export Loyalty Card Transactions
*VoucherifySdk::LoyaltiesApi* | [**get_earning_rule**](docs/LoyaltiesApi.md#get_earning_rule) | **GET** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Get Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**get_loyalty_program**](docs/LoyaltiesApi.md#get_loyalty_program) | **GET** /v1/loyalties/{campaignId} | Get Loyalty Campaign
*VoucherifySdk::LoyaltiesApi* | [**get_loyalty_tier**](docs/LoyaltiesApi.md#get_loyalty_tier) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId} | Get Loyalty Tier
*VoucherifySdk::LoyaltiesApi* | [**get_member**](docs/LoyaltiesApi.md#get_member) | **GET** /v1/loyalties/members/{memberId} | Get Member
*VoucherifySdk::LoyaltiesApi* | [**get_member1**](docs/LoyaltiesApi.md#get_member1) | **GET** /v1/loyalties/{campaignId}/members/{memberId} | Get Member
*VoucherifySdk::LoyaltiesApi* | [**get_reward_assignment1**](docs/LoyaltiesApi.md#get_reward_assignment1) | **GET** /v1/loyalties/{campaignId}/reward-assignments/{assignmentId} | Get Reward Assignment
*VoucherifySdk::LoyaltiesApi* | [**get_reward_assignment2**](docs/LoyaltiesApi.md#get_reward_assignment2) | **GET** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Get Reward Assignment
*VoucherifySdk::LoyaltiesApi* | [**get_reward_details**](docs/LoyaltiesApi.md#get_reward_details) | **GET** /v1/loyalties/{campaignId}/reward-assignments/{assignmentId}/reward | Get Reward Details
*VoucherifySdk::LoyaltiesApi* | [**list_earning_rules**](docs/LoyaltiesApi.md#list_earning_rules) | **GET** /v1/loyalties/{campaignId}/earning-rules | List Earning Rules
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_card_transactions**](docs/LoyaltiesApi.md#list_loyalty_card_transactions) | **GET** /v1/loyalties/members/{memberId}/transactions | List Loyalty Card Transactions
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_card_transactions1**](docs/LoyaltiesApi.md#list_loyalty_card_transactions1) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/transactions | List Loyalty Card Transactions
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_programs**](docs/LoyaltiesApi.md#list_loyalty_programs) | **GET** /v1/loyalties | List Loyalty Campaigns
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_tier_earning_rules**](docs/LoyaltiesApi.md#list_loyalty_tier_earning_rules) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId}/earning-rules | List Loyalty Tier Earning Rules
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_tier_rewards**](docs/LoyaltiesApi.md#list_loyalty_tier_rewards) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId}/rewards | List Loyalty Tier Rewards
*VoucherifySdk::LoyaltiesApi* | [**list_loyalty_tiers**](docs/LoyaltiesApi.md#list_loyalty_tiers) | **GET** /v1/loyalties/{campaignId}/tiers | List Loyalty Tiers
*VoucherifySdk::LoyaltiesApi* | [**list_member_activity**](docs/LoyaltiesApi.md#list_member_activity) | **GET** /v1/loyalties/members/{memberId}/activity | List Member Activity
*VoucherifySdk::LoyaltiesApi* | [**list_member_activity1**](docs/LoyaltiesApi.md#list_member_activity1) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/activity | List Member Activity
*VoucherifySdk::LoyaltiesApi* | [**list_member_loyalty_tier**](docs/LoyaltiesApi.md#list_member_loyalty_tier) | **GET** /v1/loyalties/members/{memberId}/tiers | List Member's Loyalty Tiers
*VoucherifySdk::LoyaltiesApi* | [**list_member_rewards**](docs/LoyaltiesApi.md#list_member_rewards) | **GET** /v1/loyalties/members/{memberId}/rewards | List Member Rewards
*VoucherifySdk::LoyaltiesApi* | [**list_members**](docs/LoyaltiesApi.md#list_members) | **GET** /v1/loyalties/{campaignId}/members | List Members
*VoucherifySdk::LoyaltiesApi* | [**list_points_expiration**](docs/LoyaltiesApi.md#list_points_expiration) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/points-expiration | Get Points Expiration
*VoucherifySdk::LoyaltiesApi* | [**list_reward_assignments1**](docs/LoyaltiesApi.md#list_reward_assignments1) | **GET** /v1/loyalties/{campaignId}/reward-assignments | List Reward Assignments
*VoucherifySdk::LoyaltiesApi* | [**list_reward_assignments2**](docs/LoyaltiesApi.md#list_reward_assignments2) | **GET** /v1/loyalties/{campaignId}/rewards | List Reward Assignments
*VoucherifySdk::LoyaltiesApi* | [**redeem_reward**](docs/LoyaltiesApi.md#redeem_reward) | **POST** /v1/loyalties/members/{memberId}/redemption | Redeem Reward
*VoucherifySdk::LoyaltiesApi* | [**redeem_reward1**](docs/LoyaltiesApi.md#redeem_reward1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/redemption | Redeem Reward
*VoucherifySdk::LoyaltiesApi* | [**transfer_points**](docs/LoyaltiesApi.md#transfer_points) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/transfers | Transfer Loyalty Points
*VoucherifySdk::LoyaltiesApi* | [**update_earning_rule**](docs/LoyaltiesApi.md#update_earning_rule) | **PUT** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Update Earning Rule
*VoucherifySdk::LoyaltiesApi* | [**update_loyalty_card_balance**](docs/LoyaltiesApi.md#update_loyalty_card_balance) | **POST** /v1/loyalties/members/{memberId}/balance | Add or Remove Loyalty Card Balance
*VoucherifySdk::LoyaltiesApi* | [**update_loyalty_card_balance1**](docs/LoyaltiesApi.md#update_loyalty_card_balance1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/balance | Add or Remove Loyalty Card Balance
*VoucherifySdk::LoyaltiesApi* | [**update_loyalty_program**](docs/LoyaltiesApi.md#update_loyalty_program) | **PUT** /v1/loyalties/{campaignId} | Update Loyalty Campaign
*VoucherifySdk::LoyaltiesApi* | [**update_reward_assignment1**](docs/LoyaltiesApi.md#update_reward_assignment1) | **PUT** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Update Reward Assignment
*VoucherifySdk::ManagementApi* | [**assign_user**](docs/ManagementApi.md#assign_user) | **POST** /management/v1/projects/{projectId}/users | Assign User
*VoucherifySdk::ManagementApi* | [**create_brand**](docs/ManagementApi.md#create_brand) | **POST** /management/v1/projects/{projectId}/branding | Create Brand
*VoucherifySdk::ManagementApi* | [**create_custom_event_schema**](docs/ManagementApi.md#create_custom_event_schema) | **POST** /management/v1/projects/{projectId}/custom-event-schemas | Create Custom Event Schema
*VoucherifySdk::ManagementApi* | [**create_metadata_schema**](docs/ManagementApi.md#create_metadata_schema) | **POST** /management/v1/projects/{projectId}/metadata-schemas | Create Metadata Schema
*VoucherifySdk::ManagementApi* | [**create_project**](docs/ManagementApi.md#create_project) | **POST** /management/v1/projects | Create Project
*VoucherifySdk::ManagementApi* | [**create_stacking_rules**](docs/ManagementApi.md#create_stacking_rules) | **POST** /management/v1/projects/{projectId}/stacking-rules | Create Stacking Rules
*VoucherifySdk::ManagementApi* | [**create_webhook**](docs/ManagementApi.md#create_webhook) | **POST** /management/v1/projects/{projectId}/webhooks | Create Webhook
*VoucherifySdk::ManagementApi* | [**delete_brand**](docs/ManagementApi.md#delete_brand) | **DELETE** /management/v1/projects/{projectId}/branding/{brandingId} | Delete Brand
*VoucherifySdk::ManagementApi* | [**delete_custom_event_schema**](docs/ManagementApi.md#delete_custom_event_schema) | **DELETE** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Delete Custom Event Schema
*VoucherifySdk::ManagementApi* | [**delete_metadata_schema**](docs/ManagementApi.md#delete_metadata_schema) | **DELETE** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Delete Metadata Schema
*VoucherifySdk::ManagementApi* | [**delete_project**](docs/ManagementApi.md#delete_project) | **DELETE** /management/v1/projects/{projectId} | Delete Project
*VoucherifySdk::ManagementApi* | [**delete_stacking_rules**](docs/ManagementApi.md#delete_stacking_rules) | **DELETE** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Delete Stacking Rules
*VoucherifySdk::ManagementApi* | [**delete_webhook**](docs/ManagementApi.md#delete_webhook) | **DELETE** /management/v1/projects/{projectId}/webhooks/{webhookId} | Delete Webhook
*VoucherifySdk::ManagementApi* | [**get_brand**](docs/ManagementApi.md#get_brand) | **GET** /management/v1/projects/{projectId}/branding/{brandingId} | Get Brand
*VoucherifySdk::ManagementApi* | [**get_custom_event_schema**](docs/ManagementApi.md#get_custom_event_schema) | **GET** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Get Custom Event Schema
*VoucherifySdk::ManagementApi* | [**get_metadata_schema1**](docs/ManagementApi.md#get_metadata_schema1) | **GET** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Get Metadata Schema
*VoucherifySdk::ManagementApi* | [**get_project**](docs/ManagementApi.md#get_project) | **GET** /management/v1/projects/{projectId} | Get Project
*VoucherifySdk::ManagementApi* | [**get_stacking_rules**](docs/ManagementApi.md#get_stacking_rules) | **GET** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Get Stacking Rules
*VoucherifySdk::ManagementApi* | [**get_user**](docs/ManagementApi.md#get_user) | **GET** /management/v1/projects/{projectId}/users/{userId} | Get User
*VoucherifySdk::ManagementApi* | [**get_webhook**](docs/ManagementApi.md#get_webhook) | **GET** /management/v1/projects/{projectId}/webhooks/{webhookId} | Get Webhook
*VoucherifySdk::ManagementApi* | [**invite_user**](docs/ManagementApi.md#invite_user) | **POST** /management/v1/projects/users/invite | Invite a New User
*VoucherifySdk::ManagementApi* | [**list_brands**](docs/ManagementApi.md#list_brands) | **GET** /management/v1/projects/{projectId}/branding | List Brands
*VoucherifySdk::ManagementApi* | [**list_custom_event_schemas**](docs/ManagementApi.md#list_custom_event_schemas) | **GET** /management/v1/projects/{projectId}/custom-event-schemas | List Custom Event Schemas
*VoucherifySdk::ManagementApi* | [**list_metadata_schemas1**](docs/ManagementApi.md#list_metadata_schemas1) | **GET** /management/v1/projects/{projectId}/metadata-schemas | List Metadata Schemas
*VoucherifySdk::ManagementApi* | [**list_projects**](docs/ManagementApi.md#list_projects) | **GET** /management/v1/projects | List Projects
*VoucherifySdk::ManagementApi* | [**list_stacking_rules**](docs/ManagementApi.md#list_stacking_rules) | **GET** /management/v1/projects/{projectId}/stacking-rules | List Stacking Rules
*VoucherifySdk::ManagementApi* | [**list_users**](docs/ManagementApi.md#list_users) | **GET** /management/v1/projects/{projectId}/users | List Users
*VoucherifySdk::ManagementApi* | [**list_webhooks**](docs/ManagementApi.md#list_webhooks) | **GET** /management/v1/projects/{projectId}/webhooks | List Webhooks
*VoucherifySdk::ManagementApi* | [**management_copy_campaign_template**](docs/ManagementApi.md#management_copy_campaign_template) | **POST** /management/v1/projects/{projectId}/templates/campaigns/{campaignTemplateId}/copy | Copy Campaign Template to a Project
*VoucherifySdk::ManagementApi* | [**management_list_campaign_templates**](docs/ManagementApi.md#management_list_campaign_templates) | **GET** /management/v1/projects/{projectId}/templates/campaigns | List Campaign Templates
*VoucherifySdk::ManagementApi* | [**unassign_user**](docs/ManagementApi.md#unassign_user) | **DELETE** /management/v1/projects/{projectId}/users/{userId} | Unassign User
*VoucherifySdk::ManagementApi* | [**update_brand**](docs/ManagementApi.md#update_brand) | **PUT** /management/v1/projects/{projectId}/branding/{brandingId} | Update Brand
*VoucherifySdk::ManagementApi* | [**update_custom_event_schema**](docs/ManagementApi.md#update_custom_event_schema) | **PUT** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Update Custom Event Schema
*VoucherifySdk::ManagementApi* | [**update_metadata_schema**](docs/ManagementApi.md#update_metadata_schema) | **PUT** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Update Metadata Schema
*VoucherifySdk::ManagementApi* | [**update_project**](docs/ManagementApi.md#update_project) | **PUT** /management/v1/projects/{projectId} | Update Project
*VoucherifySdk::ManagementApi* | [**update_stacking_rules**](docs/ManagementApi.md#update_stacking_rules) | **PUT** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Update Stacking Rules
*VoucherifySdk::ManagementApi* | [**update_user**](docs/ManagementApi.md#update_user) | **PUT** /management/v1/projects/{projectId}/users/{userId} | Update User
*VoucherifySdk::ManagementApi* | [**update_webhook**](docs/ManagementApi.md#update_webhook) | **PUT** /management/v1/projects/{projectId}/webhooks/{webhookId} | Update Webhook
*VoucherifySdk::MetadataSchemasApi* | [**get_metadata_schema**](docs/MetadataSchemasApi.md#get_metadata_schema) | **GET** /v1/metadata-schemas/{resource} | Get Metadata Schema
*VoucherifySdk::MetadataSchemasApi* | [**list_metadata_schemas**](docs/MetadataSchemasApi.md#list_metadata_schemas) | **GET** /v1/metadata-schemas | List Metadata Schemas
*VoucherifySdk::OrdersApi* | [**create_order**](docs/OrdersApi.md#create_order) | **POST** /v1/orders | Create Order
*VoucherifySdk::OrdersApi* | [**create_order_export**](docs/OrdersApi.md#create_order_export) | **POST** /v1/orders/export | Create Orders Export
*VoucherifySdk::OrdersApi* | [**get_order**](docs/OrdersApi.md#get_order) | **GET** /v1/orders/{orderId} | Get Order
*VoucherifySdk::OrdersApi* | [**import_orders**](docs/OrdersApi.md#import_orders) | **POST** /v1/orders/import | Import Orders
*VoucherifySdk::OrdersApi* | [**list_orders**](docs/OrdersApi.md#list_orders) | **GET** /v1/orders | List Orders
*VoucherifySdk::OrdersApi* | [**update_order**](docs/OrdersApi.md#update_order) | **PUT** /v1/orders/{orderId} | Update Order
*VoucherifySdk::ProductCollectionsApi* | [**create_product_collection**](docs/ProductCollectionsApi.md#create_product_collection) | **POST** /v1/product-collections | Create Product Collection
*VoucherifySdk::ProductCollectionsApi* | [**delete_product_collection**](docs/ProductCollectionsApi.md#delete_product_collection) | **DELETE** /v1/product-collections/{productCollectionId} | Delete Product Collection
*VoucherifySdk::ProductCollectionsApi* | [**get_product_collection**](docs/ProductCollectionsApi.md#get_product_collection) | **GET** /v1/product-collections/{productCollectionId} | Get Product Collection
*VoucherifySdk::ProductCollectionsApi* | [**list_product_collections**](docs/ProductCollectionsApi.md#list_product_collections) | **GET** /v1/product-collections | List Product Collections
*VoucherifySdk::ProductCollectionsApi* | [**list_products_in_collection**](docs/ProductCollectionsApi.md#list_products_in_collection) | **GET** /v1/product-collections/{productCollectionId}/products | List Products in Collection
*VoucherifySdk::ProductsApi* | [**create_product**](docs/ProductsApi.md#create_product) | **POST** /v1/products | Create Product
*VoucherifySdk::ProductsApi* | [**create_sku**](docs/ProductsApi.md#create_sku) | **POST** /v1/products/{productId}/skus | Create SKU
*VoucherifySdk::ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /v1/products/{productId} | Delete Product
*VoucherifySdk::ProductsApi* | [**delete_sku**](docs/ProductsApi.md#delete_sku) | **DELETE** /v1/products/{productId}/skus/{skuId} | Delete SKU
*VoucherifySdk::ProductsApi* | [**get_product**](docs/ProductsApi.md#get_product) | **GET** /v1/products/{productId} | Get Product
*VoucherifySdk::ProductsApi* | [**get_sku**](docs/ProductsApi.md#get_sku) | **GET** /v1/skus/{skuId} | Get SKU
*VoucherifySdk::ProductsApi* | [**import_products_using_csv**](docs/ProductsApi.md#import_products_using_csv) | **POST** /v1/products/importCSV | Import Products using CSV
*VoucherifySdk::ProductsApi* | [**import_skus_using_csv**](docs/ProductsApi.md#import_skus_using_csv) | **POST** /v1/skus/importCSV | Import SKUs using CSV
*VoucherifySdk::ProductsApi* | [**list_products**](docs/ProductsApi.md#list_products) | **GET** /v1/products | List Products
*VoucherifySdk::ProductsApi* | [**list_skus_in_product**](docs/ProductsApi.md#list_skus_in_product) | **GET** /v1/products/{productId}/skus | List SKUs in Product
*VoucherifySdk::ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PUT** /v1/products/{productId} | Update Product
*VoucherifySdk::ProductsApi* | [**update_products_in_bulk**](docs/ProductsApi.md#update_products_in_bulk) | **POST** /v1/products/bulk/async | Update Products in Bulk
*VoucherifySdk::ProductsApi* | [**update_products_metadata_in_bulk**](docs/ProductsApi.md#update_products_metadata_in_bulk) | **POST** /v1/products/metadata/async | Update Products' Metadata in Bulk
*VoucherifySdk::ProductsApi* | [**update_sku**](docs/ProductsApi.md#update_sku) | **PUT** /v1/products/{productId}/skus/{skuId} | Update SKU
*VoucherifySdk::PromotionsApi* | [**add_promotion_tier_to_campaign**](docs/PromotionsApi.md#add_promotion_tier_to_campaign) | **POST** /v1/promotions/{campaignId}/tiers | Add Promotion Tier to Campaign
*VoucherifySdk::PromotionsApi* | [**create_promotion_stack**](docs/PromotionsApi.md#create_promotion_stack) | **POST** /v1/promotions/{campaignId}/stacks | Create Promotion Stack
*VoucherifySdk::PromotionsApi* | [**delete_promotion_stack**](docs/PromotionsApi.md#delete_promotion_stack) | **DELETE** /v1/promotions/{campaignId}/stacks/{stackId} | Delete Promotion Stack
*VoucherifySdk::PromotionsApi* | [**delete_promotion_tier**](docs/PromotionsApi.md#delete_promotion_tier) | **DELETE** /v1/promotions/tiers/{promotionTierId} | Delete Promotion Tier
*VoucherifySdk::PromotionsApi* | [**disable_promotion_tier**](docs/PromotionsApi.md#disable_promotion_tier) | **POST** /v1/promotions/tiers/{promotionTierId}/disable | Disable Promotion Tier
*VoucherifySdk::PromotionsApi* | [**enable_promotion_tier**](docs/PromotionsApi.md#enable_promotion_tier) | **POST** /v1/promotions/tiers/{promotionTierId}/enable | Enable Promotion Tier
*VoucherifySdk::PromotionsApi* | [**get_promotion_stack**](docs/PromotionsApi.md#get_promotion_stack) | **GET** /v1/promotions/{campaignId}/stacks/{stackId} | Get Promotion Stack
*VoucherifySdk::PromotionsApi* | [**get_promotion_tier**](docs/PromotionsApi.md#get_promotion_tier) | **GET** /v1/promotions/tiers/{promotionTierId} | Get Promotion Tier
*VoucherifySdk::PromotionsApi* | [**list_all_promotion_stacks**](docs/PromotionsApi.md#list_all_promotion_stacks) | **GET** /v1/promotions/stacks | List Promotion Stacks
*VoucherifySdk::PromotionsApi* | [**list_promotion_stacks_in_campaign**](docs/PromotionsApi.md#list_promotion_stacks_in_campaign) | **GET** /v1/promotions/{campaignId}/stacks | List Promotion Stacks in Campaign
*VoucherifySdk::PromotionsApi* | [**list_promotion_tiers**](docs/PromotionsApi.md#list_promotion_tiers) | **GET** /v1/promotions/tiers | List Promotion Tiers
*VoucherifySdk::PromotionsApi* | [**list_promotion_tiers_from_campaign**](docs/PromotionsApi.md#list_promotion_tiers_from_campaign) | **GET** /v1/promotions/{campaignId}/tiers | List Promotion Tiers from Campaign
*VoucherifySdk::PromotionsApi* | [**update_promotion_stack**](docs/PromotionsApi.md#update_promotion_stack) | **PUT** /v1/promotions/{campaignId}/stacks/{stackId} | Update Promotion Stack
*VoucherifySdk::PromotionsApi* | [**update_promotion_tier**](docs/PromotionsApi.md#update_promotion_tier) | **PUT** /v1/promotions/tiers/{promotionTierId} | Update Promotion Tier
*VoucherifySdk::PublicationsApi* | [**create_publication**](docs/PublicationsApi.md#create_publication) | **POST** /v1/publications | Create Publication
*VoucherifySdk::PublicationsApi* | [**create_publication1**](docs/PublicationsApi.md#create_publication1) | **GET** /v1/publications/create | Create Publication
*VoucherifySdk::PublicationsApi* | [**list_publications**](docs/PublicationsApi.md#list_publications) | **GET** /v1/publications | List Publications
*VoucherifySdk::QualificationsApi* | [**check_eligibility**](docs/QualificationsApi.md#check_eligibility) | **POST** /v1/qualifications | Check Eligibility
*VoucherifySdk::RedemptionsApi* | [**get_redemption**](docs/RedemptionsApi.md#get_redemption) | **GET** /v1/redemptions/{redemptionId} | Get Redemption
*VoucherifySdk::RedemptionsApi* | [**get_voucher_redemptions**](docs/RedemptionsApi.md#get_voucher_redemptions) | **GET** /v1/vouchers/{code}/redemption | Get Voucher's Redemptions
*VoucherifySdk::RedemptionsApi* | [**list_redemptions**](docs/RedemptionsApi.md#list_redemptions) | **GET** /v1/redemptions | List Redemptions
*VoucherifySdk::RedemptionsApi* | [**redeem_stacked_discounts**](docs/RedemptionsApi.md#redeem_stacked_discounts) | **POST** /v1/redemptions | Redeem Stackable Discounts
*VoucherifySdk::RedemptionsApi* | [**rollback_redemption**](docs/RedemptionsApi.md#rollback_redemption) | **POST** /v1/redemptions/{redemptionId}/rollback | Rollback Redemption
*VoucherifySdk::RedemptionsApi* | [**rollback_stacked_redemptions**](docs/RedemptionsApi.md#rollback_stacked_redemptions) | **POST** /v1/redemptions/{parentRedemptionId}/rollbacks | Rollback Stackable Redemptions
*VoucherifySdk::ReferralsApi* | [**referrals_add_holders**](docs/ReferralsApi.md#referrals_add_holders) | **POST** /v1/referrals/members/{memberId}/holders | Add Referral Code Holders
*VoucherifySdk::ReferralsApi* | [**referrals_add_holders1**](docs/ReferralsApi.md#referrals_add_holders1) | **POST** /v1/referrals/{campaignId}/members/{memberId}/holders | Add Referral Code Holders
*VoucherifySdk::ReferralsApi* | [**referrals_code_holders**](docs/ReferralsApi.md#referrals_code_holders) | **GET** /v1/referrals/{campaignId}/members/{memberId}/holders | List Referral Code Holders
*VoucherifySdk::ReferralsApi* | [**referrals_code_holders1**](docs/ReferralsApi.md#referrals_code_holders1) | **GET** /v1/referrals/members/{memberId}/holders | List Referral Code Holders
*VoucherifySdk::ReferralsApi* | [**referrals_remove_holder**](docs/ReferralsApi.md#referrals_remove_holder) | **DELETE** /v1/referrals/members/{memberId}/holders/{holderId} | Remove Referral Card Holder
*VoucherifySdk::ReferralsApi* | [**referrals_remove_holder1**](docs/ReferralsApi.md#referrals_remove_holder1) | **DELETE** /v1/referrals/{campaignId}/members/{memberId}/holders/{holderId} | Remove Referral Card Holder
*VoucherifySdk::RewardsApi* | [**create_reward**](docs/RewardsApi.md#create_reward) | **POST** /v1/rewards | Create Reward
*VoucherifySdk::RewardsApi* | [**create_reward_assignment**](docs/RewardsApi.md#create_reward_assignment) | **POST** /v1/rewards/{rewardId}/assignments | Create Reward Assignment
*VoucherifySdk::RewardsApi* | [**delete_reward**](docs/RewardsApi.md#delete_reward) | **DELETE** /v1/rewards/{rewardId} | Delete Reward
*VoucherifySdk::RewardsApi* | [**delete_reward_assignment**](docs/RewardsApi.md#delete_reward_assignment) | **DELETE** /v1/rewards/{rewardId}/assignments/{assignmentId} | Delete Reward Assignment
*VoucherifySdk::RewardsApi* | [**get_reward**](docs/RewardsApi.md#get_reward) | **GET** /v1/rewards/{rewardId} | Get Reward
*VoucherifySdk::RewardsApi* | [**get_reward_assignment**](docs/RewardsApi.md#get_reward_assignment) | **GET** /v1/rewards/{rewardId}/assignments/{assignmentId} | Get Reward Assignment
*VoucherifySdk::RewardsApi* | [**list_reward_assignments**](docs/RewardsApi.md#list_reward_assignments) | **GET** /v1/rewards/{rewardId}/assignments | List Reward Assignments
*VoucherifySdk::RewardsApi* | [**list_rewards**](docs/RewardsApi.md#list_rewards) | **GET** /v1/rewards | List Rewards
*VoucherifySdk::RewardsApi* | [**update_reward**](docs/RewardsApi.md#update_reward) | **PUT** /v1/rewards/{rewardId} | Update Reward
*VoucherifySdk::RewardsApi* | [**update_reward_assignment**](docs/RewardsApi.md#update_reward_assignment) | **PUT** /v1/rewards/{rewardId}/assignments/{assignmentId} | Update Reward Assignment
*VoucherifySdk::SegmentsApi* | [**create_segment**](docs/SegmentsApi.md#create_segment) | **POST** /v1/segments | Create Segment
*VoucherifySdk::SegmentsApi* | [**delete_segment**](docs/SegmentsApi.md#delete_segment) | **DELETE** /v1/segments/{segmentId} | Delete Segment
*VoucherifySdk::SegmentsApi* | [**get_segment**](docs/SegmentsApi.md#get_segment) | **GET** /v1/segments/{segmentId} | Get Segment
*VoucherifySdk::TemplatesApi* | [**add_tier_from_template**](docs/TemplatesApi.md#add_tier_from_template) | **POST** /v1/templates/campaigns/{campaignTemplateId}/tier-setup | Add Promotion Tier From Template
*VoucherifySdk::TemplatesApi* | [**create_campaign_from_template**](docs/TemplatesApi.md#create_campaign_from_template) | **POST** /v1/templates/campaigns/{campaignTemplateId}/campaign-setup | Create Campaign From Template
*VoucherifySdk::TemplatesApi* | [**create_campaign_template**](docs/TemplatesApi.md#create_campaign_template) | **POST** /v1/templates/campaigns | Create Campaign Template
*VoucherifySdk::TemplatesApi* | [**delete_campaign_template**](docs/TemplatesApi.md#delete_campaign_template) | **DELETE** /v1/templates/campaigns/{campaignTemplateId} | Delete Campaign Template
*VoucherifySdk::TemplatesApi* | [**get_campaign_template**](docs/TemplatesApi.md#get_campaign_template) | **GET** /v1/templates/campaigns/{campaignTemplateId} | Get Campaign Template
*VoucherifySdk::TemplatesApi* | [**list_campaign_templates**](docs/TemplatesApi.md#list_campaign_templates) | **GET** /v1/templates/campaigns | List Campaign Templates
*VoucherifySdk::TemplatesApi* | [**update_campaign_template**](docs/TemplatesApi.md#update_campaign_template) | **PUT** /v1/templates/campaigns/{campaignTemplateId} | Update Campaign Template
*VoucherifySdk::ValidationRulesApi* | [**create_validation_rule_assignment**](docs/ValidationRulesApi.md#create_validation_rule_assignment) | **POST** /v1/validation-rules/{validationRuleId}/assignments | Create Validation Rules Assignments
*VoucherifySdk::ValidationRulesApi* | [**create_validation_rules**](docs/ValidationRulesApi.md#create_validation_rules) | **POST** /v1/validation-rules | Create Validation Rules
*VoucherifySdk::ValidationRulesApi* | [**delete_validation_rule_assignment**](docs/ValidationRulesApi.md#delete_validation_rule_assignment) | **DELETE** /v1/validation-rules/{validationRuleId}/assignments/{assignmentId} | Delete Validation Rule Assignment
*VoucherifySdk::ValidationRulesApi* | [**delete_validation_rules**](docs/ValidationRulesApi.md#delete_validation_rules) | **DELETE** /v1/validation-rules/{validationRuleId} | Delete Validation Rule
*VoucherifySdk::ValidationRulesApi* | [**get_validation_rule**](docs/ValidationRulesApi.md#get_validation_rule) | **GET** /v1/validation-rules/{validationRuleId} | Get Validation Rule
*VoucherifySdk::ValidationRulesApi* | [**list_validation_rule_assignments**](docs/ValidationRulesApi.md#list_validation_rule_assignments) | **GET** /v1/validation-rules/{validationRuleId}/assignments | List Validation Rule Assignments
*VoucherifySdk::ValidationRulesApi* | [**list_validation_rules**](docs/ValidationRulesApi.md#list_validation_rules) | **GET** /v1/validation-rules | List Validation Rules
*VoucherifySdk::ValidationRulesApi* | [**list_validation_rules_assignments**](docs/ValidationRulesApi.md#list_validation_rules_assignments) | **GET** /v1/validation-rules-assignments | List Validation Rules' Assignment(s)
*VoucherifySdk::ValidationRulesApi* | [**update_validation_rule**](docs/ValidationRulesApi.md#update_validation_rule) | **PUT** /v1/validation-rules/{validationRuleId} | Update Validation Rule
*VoucherifySdk::ValidationsApi* | [**validate_stacked_discounts**](docs/ValidationsApi.md#validate_stacked_discounts) | **POST** /v1/validations | Validate Stackable Discounts
*VoucherifySdk::VouchersApi* | [**create_voucher**](docs/VouchersApi.md#create_voucher) | **POST** /v1/vouchers/{code} | Create Voucher
*VoucherifySdk::VouchersApi* | [**delete_voucher**](docs/VouchersApi.md#delete_voucher) | **DELETE** /v1/vouchers/{code} | Delete Voucher
*VoucherifySdk::VouchersApi* | [**disable_voucher**](docs/VouchersApi.md#disable_voucher) | **POST** /v1/vouchers/{code}/disable | Disable Voucher
*VoucherifySdk::VouchersApi* | [**enable_voucher**](docs/VouchersApi.md#enable_voucher) | **POST** /v1/vouchers/{code}/enable | Enable Voucher
*VoucherifySdk::VouchersApi* | [**export_voucher_transactions**](docs/VouchersApi.md#export_voucher_transactions) | **POST** /v1/vouchers/{code}/transactions/export | Export Voucher Transactions
*VoucherifySdk::VouchersApi* | [**generate_random_code**](docs/VouchersApi.md#generate_random_code) | **POST** /v1/vouchers | Generate Random Code
*VoucherifySdk::VouchersApi* | [**get_voucher**](docs/VouchersApi.md#get_voucher) | **GET** /v1/vouchers/{code} | Get Voucher
*VoucherifySdk::VouchersApi* | [**import_vouchers**](docs/VouchersApi.md#import_vouchers) | **POST** /v1/vouchers/import | Import Vouchers
*VoucherifySdk::VouchersApi* | [**import_vouchers_using_csv**](docs/VouchersApi.md#import_vouchers_using_csv) | **POST** /v1/vouchers/importCSV | Import Vouchers using CSV
*VoucherifySdk::VouchersApi* | [**list_voucher_transactions**](docs/VouchersApi.md#list_voucher_transactions) | **GET** /v1/vouchers/{code}/transactions | List Voucher Transactions
*VoucherifySdk::VouchersApi* | [**list_vouchers**](docs/VouchersApi.md#list_vouchers) | **GET** /v1/vouchers | List Vouchers
*VoucherifySdk::VouchersApi* | [**release_validation_session**](docs/VouchersApi.md#release_validation_session) | **DELETE** /v1/vouchers/{code}/sessions/{sessionKey} | Release Validation Session
*VoucherifySdk::VouchersApi* | [**update_voucher**](docs/VouchersApi.md#update_voucher) | **PUT** /v1/vouchers/{code} | Update Voucher
*VoucherifySdk::VouchersApi* | [**update_voucher_balance**](docs/VouchersApi.md#update_voucher_balance) | **POST** /v1/vouchers/{code}/balance | Add or Remove Voucher Balance
*VoucherifySdk::VouchersApi* | [**update_vouchers_in_bulk**](docs/VouchersApi.md#update_vouchers_in_bulk) | **POST** /v1/vouchers/bulk/async | Update Vouchers in Bulk
*VoucherifySdk::VouchersApi* | [**update_vouchers_metadata_in_bulk**](docs/VouchersApi.md#update_vouchers_metadata_in_bulk) | **POST** /v1/vouchers/metadata/async | Update Vouchers' Metadata in Bulk


## 📚 Documentation for Models

 - [VoucherifySdk::AccessSettingsCampaignAssignmentsList](docs/AccessSettingsCampaignAssignmentsList.md)
 - [VoucherifySdk::ApplicableTo](docs/ApplicableTo.md)
 - [VoucherifySdk::ApplicableToEffect](docs/ApplicableToEffect.md)
 - [VoucherifySdk::ApplicableToResultList](docs/ApplicableToResultList.md)
 - [VoucherifySdk::AreaStoreCampaignAssignment](docs/AreaStoreCampaignAssignment.md)
 - [VoucherifySdk::AsyncActionBase](docs/AsyncActionBase.md)
 - [VoucherifySdk::AsyncActionGetResponseBody](docs/AsyncActionGetResponseBody.md)
 - [VoucherifySdk::AsyncActionsListResponseBody](docs/AsyncActionsListResponseBody.md)
 - [VoucherifySdk::BusValRuleAssignment](docs/BusValRuleAssignment.md)
 - [VoucherifySdk::Campaign](docs/Campaign.md)
 - [VoucherifySdk::CampaignBase](docs/CampaignBase.md)
 - [VoucherifySdk::CampaignLoyaltyCard](docs/CampaignLoyaltyCard.md)
 - [VoucherifySdk::CampaignLoyaltyCardExpirationRules](docs/CampaignLoyaltyCardExpirationRules.md)
 - [VoucherifySdk::CampaignLoyaltyVoucher](docs/CampaignLoyaltyVoucher.md)
 - [VoucherifySdk::CampaignLoyaltyVoucherRedemption](docs/CampaignLoyaltyVoucherRedemption.md)
 - [VoucherifySdk::CampaignTemplate](docs/CampaignTemplate.md)
 - [VoucherifySdk::CampaignVoucher](docs/CampaignVoucher.md)
 - [VoucherifySdk::CampaignVoucherRedemption](docs/CampaignVoucherRedemption.md)
 - [VoucherifySdk::CampaignsCreateRequestBody](docs/CampaignsCreateRequestBody.md)
 - [VoucherifySdk::CampaignsCreateRequestBodyPromotion](docs/CampaignsCreateRequestBodyPromotion.md)
 - [VoucherifySdk::CampaignsCreateRequestBodyVoucher](docs/CampaignsCreateRequestBodyVoucher.md)
 - [VoucherifySdk::CampaignsCreateRequestBodyVoucherRedemption](docs/CampaignsCreateRequestBodyVoucherRedemption.md)
 - [VoucherifySdk::CampaignsCreateResponseBody](docs/CampaignsCreateResponseBody.md)
 - [VoucherifySdk::CampaignsDeleteResponseBody](docs/CampaignsDeleteResponseBody.md)
 - [VoucherifySdk::CampaignsGetResponseBody](docs/CampaignsGetResponseBody.md)
 - [VoucherifySdk::CampaignsImportCreateResponseBody](docs/CampaignsImportCreateResponseBody.md)
 - [VoucherifySdk::CampaignsImportCsvCreateResponseBody](docs/CampaignsImportCsvCreateResponseBody.md)
 - [VoucherifySdk::CampaignsImportVoucherItem](docs/CampaignsImportVoucherItem.md)
 - [VoucherifySdk::CampaignsImportVoucherItemRedemption](docs/CampaignsImportVoucherItemRedemption.md)
 - [VoucherifySdk::CampaignsListResponseBody](docs/CampaignsListResponseBody.md)
 - [VoucherifySdk::CampaignsUpdateRequestBody](docs/CampaignsUpdateRequestBody.md)
 - [VoucherifySdk::CampaignsUpdateRequestBodyOptions](docs/CampaignsUpdateRequestBodyOptions.md)
 - [VoucherifySdk::CampaignsUpdateResponseBody](docs/CampaignsUpdateResponseBody.md)
 - [VoucherifySdk::CampaignsVouchersCreateCombinedResponseBody](docs/CampaignsVouchersCreateCombinedResponseBody.md)
 - [VoucherifySdk::CampaignsVouchersCreateCombinedResponseBodyGift](docs/CampaignsVouchersCreateCombinedResponseBodyGift.md)
 - [VoucherifySdk::CampaignsVouchersCreateCombinedResponseBodyLoyaltyCard](docs/CampaignsVouchersCreateCombinedResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::CampaignsVouchersCreateCombinedResponseBodyPublish](docs/CampaignsVouchersCreateCombinedResponseBodyPublish.md)
 - [VoucherifySdk::CampaignsVouchersCreateCombinedResponseBodyRedemption](docs/CampaignsVouchersCreateCombinedResponseBodyRedemption.md)
 - [VoucherifySdk::CampaignsVouchersCreateInBulkRequestBody](docs/CampaignsVouchersCreateInBulkRequestBody.md)
 - [VoucherifySdk::CampaignsVouchersCreateInBulkRequestBodyRedemption](docs/CampaignsVouchersCreateInBulkRequestBodyRedemption.md)
 - [VoucherifySdk::CampaignsVouchersCreateRequestBody](docs/CampaignsVouchersCreateRequestBody.md)
 - [VoucherifySdk::CampaignsVouchersCreateRequestBodyRedemption](docs/CampaignsVouchersCreateRequestBodyRedemption.md)
 - [VoucherifySdk::CampaignsVouchersCreateResponseBody](docs/CampaignsVouchersCreateResponseBody.md)
 - [VoucherifySdk::CampaignsVouchersCreateResponseBodyGift](docs/CampaignsVouchersCreateResponseBodyGift.md)
 - [VoucherifySdk::CampaignsVouchersCreateResponseBodyLoyaltyCard](docs/CampaignsVouchersCreateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::CampaignsVouchersCreateResponseBodyPublish](docs/CampaignsVouchersCreateResponseBodyPublish.md)
 - [VoucherifySdk::CampaignsVouchersCreateResponseBodyRedemption](docs/CampaignsVouchersCreateResponseBodyRedemption.md)
 - [VoucherifySdk::CategoriesCreateRequestBody](docs/CategoriesCreateRequestBody.md)
 - [VoucherifySdk::CategoriesCreateResponseBody](docs/CategoriesCreateResponseBody.md)
 - [VoucherifySdk::CategoriesGetResponseBody](docs/CategoriesGetResponseBody.md)
 - [VoucherifySdk::CategoriesListResponseBody](docs/CategoriesListResponseBody.md)
 - [VoucherifySdk::CategoriesUpdateRequestBody](docs/CategoriesUpdateRequestBody.md)
 - [VoucherifySdk::CategoriesUpdateResponseBody](docs/CategoriesUpdateResponseBody.md)
 - [VoucherifySdk::Category](docs/Category.md)
 - [VoucherifySdk::CategoryWithStackingRulesType](docs/CategoryWithStackingRulesType.md)
 - [VoucherifySdk::ClientEventsCreateRequestBody](docs/ClientEventsCreateRequestBody.md)
 - [VoucherifySdk::ClientEventsCreateRequestBodyLoyalty](docs/ClientEventsCreateRequestBodyLoyalty.md)
 - [VoucherifySdk::ClientEventsCreateRequestBodyReferral](docs/ClientEventsCreateRequestBodyReferral.md)
 - [VoucherifySdk::ClientEventsCreateResponseBody](docs/ClientEventsCreateResponseBody.md)
 - [VoucherifySdk::ClientPromotionsTiersListResponseBody](docs/ClientPromotionsTiersListResponseBody.md)
 - [VoucherifySdk::ClientQualificationsCheckEligibilityRequestBody](docs/ClientQualificationsCheckEligibilityRequestBody.md)
 - [VoucherifySdk::ClientQualificationsCheckEligibilityResponseBody](docs/ClientQualificationsCheckEligibilityResponseBody.md)
 - [VoucherifySdk::ClientRedemptionsRedeemRequestBody](docs/ClientRedemptionsRedeemRequestBody.md)
 - [VoucherifySdk::ClientRedemptionsRedeemRequestBodyOptions](docs/ClientRedemptionsRedeemRequestBodyOptions.md)
 - [VoucherifySdk::ClientRedemptionsRedeemRequestBodyRedeemablesItem](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItem.md)
 - [VoucherifySdk::ClientRedemptionsRedeemRequestBodyRedeemablesItemGift](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItemGift.md)
 - [VoucherifySdk::ClientRedemptionsRedeemRequestBodyRedeemablesItemReward](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItemReward.md)
 - [VoucherifySdk::ClientRedemptionsRedeemResponseBody](docs/ClientRedemptionsRedeemResponseBody.md)
 - [VoucherifySdk::ClientValidationsValidateRequestBody](docs/ClientValidationsValidateRequestBody.md)
 - [VoucherifySdk::ClientValidationsValidateRequestBodyOptions](docs/ClientValidationsValidateRequestBodyOptions.md)
 - [VoucherifySdk::ClientValidationsValidateRequestBodyRedeemablesItem](docs/ClientValidationsValidateRequestBodyRedeemablesItem.md)
 - [VoucherifySdk::ClientValidationsValidateRequestBodyRedeemablesItemGift](docs/ClientValidationsValidateRequestBodyRedeemablesItemGift.md)
 - [VoucherifySdk::ClientValidationsValidateRequestBodyRedeemablesItemReward](docs/ClientValidationsValidateRequestBodyRedeemablesItemReward.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBody](docs/ClientValidationsValidateResponseBody.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItem](docs/ClientValidationsValidateResponseBodyRedeemablesItem.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResult](docs/ClientValidationsValidateResponseBodyRedeemablesItemResult.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResultDetails](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDetails.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResultDiscount](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDiscount.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResultGift](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultGift.md)
 - [VoucherifySdk::ClientValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard.md)
 - [VoucherifySdk::CodeConfig](docs/CodeConfig.md)
 - [VoucherifySdk::CreatePublicationCampaign](docs/CreatePublicationCampaign.md)
 - [VoucherifySdk::Customer](docs/Customer.md)
 - [VoucherifySdk::CustomerActivity](docs/CustomerActivity.md)
 - [VoucherifySdk::CustomerAddress](docs/CustomerAddress.md)
 - [VoucherifySdk::CustomerId](docs/CustomerId.md)
 - [VoucherifySdk::CustomerLoyalty](docs/CustomerLoyalty.md)
 - [VoucherifySdk::CustomerLoyaltyCampaignsEntry](docs/CustomerLoyaltyCampaignsEntry.md)
 - [VoucherifySdk::CustomerRedeemable](docs/CustomerRedeemable.md)
 - [VoucherifySdk::CustomerRedeemableRedeemable](docs/CustomerRedeemableRedeemable.md)
 - [VoucherifySdk::CustomerReferrals](docs/CustomerReferrals.md)
 - [VoucherifySdk::CustomerReferralsCampaignsItem](docs/CustomerReferralsCampaignsItem.md)
 - [VoucherifySdk::CustomerSummary](docs/CustomerSummary.md)
 - [VoucherifySdk::CustomerSummaryOrders](docs/CustomerSummaryOrders.md)
 - [VoucherifySdk::CustomerSummaryRedemptions](docs/CustomerSummaryRedemptions.md)
 - [VoucherifySdk::CustomerSummaryRedemptionsGift](docs/CustomerSummaryRedemptionsGift.md)
 - [VoucherifySdk::CustomerSummaryRedemptionsLoyaltyCard](docs/CustomerSummaryRedemptionsLoyaltyCard.md)
 - [VoucherifySdk::CustomerWithSummaryLoyaltyReferrals](docs/CustomerWithSummaryLoyaltyReferrals.md)
 - [VoucherifySdk::CustomerWithSummaryLoyaltyReferralsAddress](docs/CustomerWithSummaryLoyaltyReferralsAddress.md)
 - [VoucherifySdk::CustomerWithSummaryLoyaltyReferralsAssets](docs/CustomerWithSummaryLoyaltyReferralsAssets.md)
 - [VoucherifySdk::CustomersActivitiesListResponseBody](docs/CustomersActivitiesListResponseBody.md)
 - [VoucherifySdk::CustomersActivityListResponseBody](docs/CustomersActivityListResponseBody.md)
 - [VoucherifySdk::CustomersCreateRequestBody](docs/CustomersCreateRequestBody.md)
 - [VoucherifySdk::CustomersCreateRequestBodyAddress](docs/CustomersCreateRequestBodyAddress.md)
 - [VoucherifySdk::CustomersCreateResponseBody](docs/CustomersCreateResponseBody.md)
 - [VoucherifySdk::CustomersCreateResponseBodyAddress](docs/CustomersCreateResponseBodyAddress.md)
 - [VoucherifySdk::CustomersCreateResponseBodyAssets](docs/CustomersCreateResponseBodyAssets.md)
 - [VoucherifySdk::CustomersGetResponseBody](docs/CustomersGetResponseBody.md)
 - [VoucherifySdk::CustomersGetResponseBodyAddress](docs/CustomersGetResponseBodyAddress.md)
 - [VoucherifySdk::CustomersGetResponseBodyAssets](docs/CustomersGetResponseBodyAssets.md)
 - [VoucherifySdk::CustomersImportCsvCreateResponseBody](docs/CustomersImportCsvCreateResponseBody.md)
 - [VoucherifySdk::CustomersListResponseBody](docs/CustomersListResponseBody.md)
 - [VoucherifySdk::CustomersMetadataUpdateInBulkRequestBody](docs/CustomersMetadataUpdateInBulkRequestBody.md)
 - [VoucherifySdk::CustomersMetadataUpdateInBulkResponseBody](docs/CustomersMetadataUpdateInBulkResponseBody.md)
 - [VoucherifySdk::CustomersPermanentDeletionCreateResponseBody](docs/CustomersPermanentDeletionCreateResponseBody.md)
 - [VoucherifySdk::CustomersPermanentDeletionCreateResponseBodyDataJson](docs/CustomersPermanentDeletionCreateResponseBodyDataJson.md)
 - [VoucherifySdk::CustomersRedeemablesListResponseBody](docs/CustomersRedeemablesListResponseBody.md)
 - [VoucherifySdk::CustomersSegmentsListResponseBody](docs/CustomersSegmentsListResponseBody.md)
 - [VoucherifySdk::CustomersUpdateInBulkRequestBody](docs/CustomersUpdateInBulkRequestBody.md)
 - [VoucherifySdk::CustomersUpdateInBulkRequestBodyAddress](docs/CustomersUpdateInBulkRequestBodyAddress.md)
 - [VoucherifySdk::CustomersUpdateInBulkResponseBody](docs/CustomersUpdateInBulkResponseBody.md)
 - [VoucherifySdk::CustomersUpdateRequestBody](docs/CustomersUpdateRequestBody.md)
 - [VoucherifySdk::CustomersUpdateRequestBodyAddress](docs/CustomersUpdateRequestBodyAddress.md)
 - [VoucherifySdk::CustomersUpdateResponseBody](docs/CustomersUpdateResponseBody.md)
 - [VoucherifySdk::CustomersUpdateResponseBodyAddress](docs/CustomersUpdateResponseBodyAddress.md)
 - [VoucherifySdk::CustomersUpdateResponseBodyAssets](docs/CustomersUpdateResponseBodyAssets.md)
 - [VoucherifySdk::Discount](docs/Discount.md)
 - [VoucherifySdk::DiscountProduct](docs/DiscountProduct.md)
 - [VoucherifySdk::DiscountUnitMultipleOneUnit](docs/DiscountUnitMultipleOneUnit.md)
 - [VoucherifySdk::EarningRule](docs/EarningRule.md)
 - [VoucherifySdk::EarningRuleCustomEvent](docs/EarningRuleCustomEvent.md)
 - [VoucherifySdk::EarningRuleLoyalty](docs/EarningRuleLoyalty.md)
 - [VoucherifySdk::EarningRuleLoyaltyCustomEvent](docs/EarningRuleLoyaltyCustomEvent.md)
 - [VoucherifySdk::EarningRuleLoyaltyCustomEventMetadata](docs/EarningRuleLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::EarningRuleLoyaltyCustomer](docs/EarningRuleLoyaltyCustomer.md)
 - [VoucherifySdk::EarningRuleLoyaltyCustomerMetadata](docs/EarningRuleLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrder](docs/EarningRuleLoyaltyOrder.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderAmount](docs/EarningRuleLoyaltyOrderAmount.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderItems](docs/EarningRuleLoyaltyOrderItems.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderItemsAmount](docs/EarningRuleLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderItemsQuantity](docs/EarningRuleLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderItemsSubtotalAmount](docs/EarningRuleLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderMetadata](docs/EarningRuleLoyaltyOrderMetadata.md)
 - [VoucherifySdk::EarningRuleLoyaltyOrderTotalAmount](docs/EarningRuleLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::EarningRuleLoyaltyTier](docs/EarningRuleLoyaltyTier.md)
 - [VoucherifySdk::EarningRuleSegment](docs/EarningRuleSegment.md)
 - [VoucherifySdk::EarningRuleSource](docs/EarningRuleSource.md)
 - [VoucherifySdk::Error](docs/Error.md)
 - [VoucherifySdk::EventsCreateRequestBody](docs/EventsCreateRequestBody.md)
 - [VoucherifySdk::EventsCreateRequestBodyLoyalty](docs/EventsCreateRequestBodyLoyalty.md)
 - [VoucherifySdk::EventsCreateRequestBodyReferral](docs/EventsCreateRequestBodyReferral.md)
 - [VoucherifySdk::EventsCreateResponseBody](docs/EventsCreateResponseBody.md)
 - [VoucherifySdk::Export](docs/Export.md)
 - [VoucherifySdk::ExportOrderFields](docs/ExportOrderFields.md)
 - [VoucherifySdk::ExportOrderOrder](docs/ExportOrderOrder.md)
 - [VoucherifySdk::ExportParameters](docs/ExportParameters.md)
 - [VoucherifySdk::ExportResult](docs/ExportResult.md)
 - [VoucherifySdk::ExportVoucherTransactionsFields](docs/ExportVoucherTransactionsFields.md)
 - [VoucherifySdk::ExportVoucherTransactionsFilters](docs/ExportVoucherTransactionsFilters.md)
 - [VoucherifySdk::ExportVoucherTransactionsOrder](docs/ExportVoucherTransactionsOrder.md)
 - [VoucherifySdk::ExportsCreateRequestBody](docs/ExportsCreateRequestBody.md)
 - [VoucherifySdk::ExportsCreateRequestBodyParameters](docs/ExportsCreateRequestBodyParameters.md)
 - [VoucherifySdk::ExportsCreateResponseBody](docs/ExportsCreateResponseBody.md)
 - [VoucherifySdk::ExportsCreateResponseBodyParameters](docs/ExportsCreateResponseBodyParameters.md)
 - [VoucherifySdk::ExportsGetResponseBody](docs/ExportsGetResponseBody.md)
 - [VoucherifySdk::ExportsGetResponseBodyParameters](docs/ExportsGetResponseBodyParameters.md)
 - [VoucherifySdk::ExportsGetResponseBodyResult](docs/ExportsGetResponseBodyResult.md)
 - [VoucherifySdk::ExportsListResponseBody](docs/ExportsListResponseBody.md)
 - [VoucherifySdk::FieldConditions](docs/FieldConditions.md)
 - [VoucherifySdk::FilterConditionsDateTime](docs/FilterConditionsDateTime.md)
 - [VoucherifySdk::FilterConditionsString](docs/FilterConditionsString.md)
 - [VoucherifySdk::FiltersCondition](docs/FiltersCondition.md)
 - [VoucherifySdk::Gift](docs/Gift.md)
 - [VoucherifySdk::InapplicableTo](docs/InapplicableTo.md)
 - [VoucherifySdk::InapplicableToResultList](docs/InapplicableToResultList.md)
 - [VoucherifySdk::Junction](docs/Junction.md)
 - [VoucherifySdk::ListPublicationsItemVoucher](docs/ListPublicationsItemVoucher.md)
 - [VoucherifySdk::Location](docs/Location.md)
 - [VoucherifySdk::LocationShape](docs/LocationShape.md)
 - [VoucherifySdk::LocationShapeDistance](docs/LocationShapeDistance.md)
 - [VoucherifySdk::LocationShapeGeojson](docs/LocationShapeGeojson.md)
 - [VoucherifySdk::LocationsGetResponseBody](docs/LocationsGetResponseBody.md)
 - [VoucherifySdk::LocationsGetResponseBodyShape](docs/LocationsGetResponseBodyShape.md)
 - [VoucherifySdk::LocationsGetResponseBodyShapeDistance](docs/LocationsGetResponseBodyShapeDistance.md)
 - [VoucherifySdk::LocationsGetResponseBodyShapeGeojson](docs/LocationsGetResponseBodyShapeGeojson.md)
 - [VoucherifySdk::LocationsListResponseBody](docs/LocationsListResponseBody.md)
 - [VoucherifySdk::LoyaltiesCreateCampaignRequestBody](docs/LoyaltiesCreateCampaignRequestBody.md)
 - [VoucherifySdk::LoyaltiesCreateCampaignResponseBody](docs/LoyaltiesCreateCampaignResponseBody.md)
 - [VoucherifySdk::LoyaltiesDeleteResponseBody](docs/LoyaltiesDeleteResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItem](docs/LoyaltiesEarningRulesCreateRequestBodyItem.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemCustomEvent](docs/LoyaltiesEarningRulesCreateRequestBodyItemCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyalty](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEvent](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomer](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrder](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItems](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyTier](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemSegment](docs/LoyaltiesEarningRulesCreateRequestBodyItemSegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateRequestBodyItemSource](docs/LoyaltiesEarningRulesCreateRequestBodyItemSource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBody](docs/LoyaltiesEarningRulesCreateResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyCustomEvent](docs/LoyaltiesEarningRulesCreateResponseBodyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyalty](docs/LoyaltiesEarningRulesCreateResponseBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodySegment](docs/LoyaltiesEarningRulesCreateResponseBodySegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesCreateResponseBodySource](docs/LoyaltiesEarningRulesCreateResponseBodySource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBody](docs/LoyaltiesEarningRulesDisableResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyCustomEvent](docs/LoyaltiesEarningRulesDisableResponseBodyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyalty](docs/LoyaltiesEarningRulesDisableResponseBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodySegment](docs/LoyaltiesEarningRulesDisableResponseBodySegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesDisableResponseBodySource](docs/LoyaltiesEarningRulesDisableResponseBodySource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBody](docs/LoyaltiesEarningRulesEnableResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyCustomEvent](docs/LoyaltiesEarningRulesEnableResponseBodyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyalty](docs/LoyaltiesEarningRulesEnableResponseBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodySegment](docs/LoyaltiesEarningRulesEnableResponseBodySegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesEnableResponseBodySource](docs/LoyaltiesEarningRulesEnableResponseBodySource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBody](docs/LoyaltiesEarningRulesGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyCustomEvent](docs/LoyaltiesEarningRulesGetResponseBodyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyalty](docs/LoyaltiesEarningRulesGetResponseBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodySegment](docs/LoyaltiesEarningRulesGetResponseBodySegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesGetResponseBodySource](docs/LoyaltiesEarningRulesGetResponseBodySource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesListResponseBody](docs/LoyaltiesEarningRulesListResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBody](docs/LoyaltiesEarningRulesUpdateRequestBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyalty](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrder](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateRequestBodySource](docs/LoyaltiesEarningRulesUpdateRequestBodySource.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBody](docs/LoyaltiesEarningRulesUpdateResponseBody.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyCustomEvent](docs/LoyaltiesEarningRulesUpdateResponseBodyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyalty](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyalty.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEvent.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEventMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomer.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomerMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrder.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItems.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsQuantity.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderMetadata.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderTotalAmount.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyTier.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodySegment](docs/LoyaltiesEarningRulesUpdateResponseBodySegment.md)
 - [VoucherifySdk::LoyaltiesEarningRulesUpdateResponseBodySource](docs/LoyaltiesEarningRulesUpdateResponseBodySource.md)
 - [VoucherifySdk::LoyaltiesGetCampaignResponseBody](docs/LoyaltiesGetCampaignResponseBody.md)
 - [VoucherifySdk::LoyaltiesListCampaignsResponseBody](docs/LoyaltiesListCampaignsResponseBody.md)
 - [VoucherifySdk::LoyaltiesListMembersResponseBody](docs/LoyaltiesListMembersResponseBody.md)
 - [VoucherifySdk::LoyaltiesLoyaltyTierReward](docs/LoyaltiesLoyaltyTierReward.md)
 - [VoucherifySdk::LoyaltiesMemberActivityListResponseBody](docs/LoyaltiesMemberActivityListResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersBalanceUpdateRequestBody](docs/LoyaltiesMembersBalanceUpdateRequestBody.md)
 - [VoucherifySdk::LoyaltiesMembersBalanceUpdateResponseBody](docs/LoyaltiesMembersBalanceUpdateResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersBalanceUpdateResponseBodyRelatedObject](docs/LoyaltiesMembersBalanceUpdateResponseBodyRelatedObject.md)
 - [VoucherifySdk::LoyaltiesMembersCreateRequestBody](docs/LoyaltiesMembersCreateRequestBody.md)
 - [VoucherifySdk::LoyaltiesMembersCreateResponseBody](docs/LoyaltiesMembersCreateResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersCreateResponseBodyLoyaltyCard](docs/LoyaltiesMembersCreateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::LoyaltiesMembersCreateResponseBodyPublish](docs/LoyaltiesMembersCreateResponseBodyPublish.md)
 - [VoucherifySdk::LoyaltiesMembersCreateResponseBodyRedemption](docs/LoyaltiesMembersCreateResponseBodyRedemption.md)
 - [VoucherifySdk::LoyaltiesMembersGetResponseBody](docs/LoyaltiesMembersGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersGetResponseBodyLoyaltyCard](docs/LoyaltiesMembersGetResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::LoyaltiesMembersGetResponseBodyPublish](docs/LoyaltiesMembersGetResponseBodyPublish.md)
 - [VoucherifySdk::LoyaltiesMembersGetResponseBodyRedemption](docs/LoyaltiesMembersGetResponseBodyRedemption.md)
 - [VoucherifySdk::LoyaltiesMembersPointsExpirationListResponseBody](docs/LoyaltiesMembersPointsExpirationListResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersPointsExpirationListResponseBodyDataItem](docs/LoyaltiesMembersPointsExpirationListResponseBodyDataItem.md)
 - [VoucherifySdk::LoyaltiesMembersPointsExpirationListResponseBodyDataItemBucket](docs/LoyaltiesMembersPointsExpirationListResponseBodyDataItemBucket.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemRequestBody](docs/LoyaltiesMembersRedemptionRedeemRequestBody.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemRequestBodyReward](docs/LoyaltiesMembersRedemptionRedeemRequestBodyReward.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBody](docs/LoyaltiesMembersRedemptionRedeemResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyChannel](docs/LoyaltiesMembersRedemptionRedeemResponseBodyChannel.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyGift](docs/LoyaltiesMembersRedemptionRedeemResponseBodyGift.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyLoyaltyCard](docs/LoyaltiesMembersRedemptionRedeemResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptions](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptions.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRedemptionsItem](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRollbacksItem](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyVoucher](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucher.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyVoucherGift](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherGift.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyVoucherLoyaltyCard](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherLoyaltyCard.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyVoucherPublish](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherPublish.md)
 - [VoucherifySdk::LoyaltiesMembersRedemptionRedeemResponseBodyVoucherRedemption](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherRedemption.md)
 - [VoucherifySdk::LoyaltiesMembersRewardsListResponseBody](docs/LoyaltiesMembersRewardsListResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersRewardsListResponseBodyDataItem](docs/LoyaltiesMembersRewardsListResponseBodyDataItem.md)
 - [VoucherifySdk::LoyaltiesMembersTiersListResponseBody](docs/LoyaltiesMembersTiersListResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersTransactionsExportCreateRequestBody](docs/LoyaltiesMembersTransactionsExportCreateRequestBody.md)
 - [VoucherifySdk::LoyaltiesMembersTransactionsExportCreateRequestBodyParameters](docs/LoyaltiesMembersTransactionsExportCreateRequestBodyParameters.md)
 - [VoucherifySdk::LoyaltiesMembersTransactionsExportCreateResponseBody](docs/LoyaltiesMembersTransactionsExportCreateResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersTransactionsExportCreateResponseBodyParameters](docs/LoyaltiesMembersTransactionsExportCreateResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesMembersTransactionsListResponseBody](docs/LoyaltiesMembersTransactionsListResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBody](docs/LoyaltiesMembersTransfersCreateResponseBody.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyAssets](docs/LoyaltiesMembersTransfersCreateResponseBodyAssets.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyAssetsBarcode](docs/LoyaltiesMembersTransfersCreateResponseBodyAssetsBarcode.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyAssetsQr](docs/LoyaltiesMembersTransfersCreateResponseBodyAssetsQr.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyLoyaltyCard](docs/LoyaltiesMembersTransfersCreateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyPublish](docs/LoyaltiesMembersTransfersCreateResponseBodyPublish.md)
 - [VoucherifySdk::LoyaltiesMembersTransfersCreateResponseBodyRedemption](docs/LoyaltiesMembersTransfersCreateResponseBodyRedemption.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBody](docs/LoyaltiesPointsExpirationExportCreateRequestBody.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParameters](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParameters.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParametersFilters](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFilters.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignId](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignId.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignIdConditions](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignIdConditions.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherId](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherId.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherIdConditions](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherIdConditions.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBody](docs/LoyaltiesPointsExpirationExportCreateResponseBody.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParameters](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParametersFilters](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFilters.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignId](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignId.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignIdConditions](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignIdConditions.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherId](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherId.md)
 - [VoucherifySdk::LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherIdConditions](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherIdConditions.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsGetResponseBody](docs/LoyaltiesRewardAssignmentsGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsGetResponseBodyParameters](docs/LoyaltiesRewardAssignmentsGetResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsGetResponseBodyParametersLoyalty](docs/LoyaltiesRewardAssignmentsGetResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsListResponseBody](docs/LoyaltiesRewardAssignmentsListResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsRewardGetResponseBody](docs/LoyaltiesRewardAssignmentsRewardGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardAssignmentsRewardGetResponseBodyAttributes](docs/LoyaltiesRewardAssignmentsRewardGetResponseBodyAttributes.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentItemRequestBody](docs/LoyaltiesRewardsCreateAssignmentItemRequestBody.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentItemRequestBodyParameters](docs/LoyaltiesRewardsCreateAssignmentItemRequestBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentItemRequestBodyParametersLoyalty](docs/LoyaltiesRewardsCreateAssignmentItemRequestBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentResponseBody](docs/LoyaltiesRewardsCreateAssignmentResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentResponseBodyParameters](docs/LoyaltiesRewardsCreateAssignmentResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardsCreateAssignmentResponseBodyParametersLoyalty](docs/LoyaltiesRewardsCreateAssignmentResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesRewardsGetResponseBody](docs/LoyaltiesRewardsGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardsGetResponseBodyParameters](docs/LoyaltiesRewardsGetResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardsGetResponseBodyParametersLoyalty](docs/LoyaltiesRewardsGetResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesRewardsListAssignmentsResponseBody](docs/LoyaltiesRewardsListAssignmentsResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentRequestBody](docs/LoyaltiesRewardsUpdateAssignmentRequestBody.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentRequestBodyParameters](docs/LoyaltiesRewardsUpdateAssignmentRequestBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentRequestBodyParametersLoyalty](docs/LoyaltiesRewardsUpdateAssignmentRequestBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentResponseBody](docs/LoyaltiesRewardsUpdateAssignmentResponseBody.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentResponseBodyParameters](docs/LoyaltiesRewardsUpdateAssignmentResponseBodyParameters.md)
 - [VoucherifySdk::LoyaltiesRewardsUpdateAssignmentResponseBodyParametersLoyalty](docs/LoyaltiesRewardsUpdateAssignmentResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::LoyaltiesTiersCreateInBulkRequestBodyItem](docs/LoyaltiesTiersCreateInBulkRequestBodyItem.md)
 - [VoucherifySdk::LoyaltiesTiersEarningRulesListResponseBody](docs/LoyaltiesTiersEarningRulesListResponseBody.md)
 - [VoucherifySdk::LoyaltiesTiersGetResponseBody](docs/LoyaltiesTiersGetResponseBody.md)
 - [VoucherifySdk::LoyaltiesTiersGetResponseBodyConfig](docs/LoyaltiesTiersGetResponseBodyConfig.md)
 - [VoucherifySdk::LoyaltiesTiersGetResponseBodyConfigPoints](docs/LoyaltiesTiersGetResponseBodyConfigPoints.md)
 - [VoucherifySdk::LoyaltiesTiersGetResponseBodyPoints](docs/LoyaltiesTiersGetResponseBodyPoints.md)
 - [VoucherifySdk::LoyaltiesTiersListResponseBody](docs/LoyaltiesTiersListResponseBody.md)
 - [VoucherifySdk::LoyaltiesTiersRewardsListResponseBody](docs/LoyaltiesTiersRewardsListResponseBody.md)
 - [VoucherifySdk::LoyaltiesTransferPoints](docs/LoyaltiesTransferPoints.md)
 - [VoucherifySdk::LoyaltiesUpdateCampaignRequestBody](docs/LoyaltiesUpdateCampaignRequestBody.md)
 - [VoucherifySdk::LoyaltiesUpdateCampaignRequestBodyOptions](docs/LoyaltiesUpdateCampaignRequestBodyOptions.md)
 - [VoucherifySdk::LoyaltiesUpdateCampaignResponseBody](docs/LoyaltiesUpdateCampaignResponseBody.md)
 - [VoucherifySdk::LoyaltyCampaign](docs/LoyaltyCampaign.md)
 - [VoucherifySdk::LoyaltyCampaignVoucher](docs/LoyaltyCampaignVoucher.md)
 - [VoucherifySdk::LoyaltyCampaignVoucherRedemption](docs/LoyaltyCampaignVoucherRedemption.md)
 - [VoucherifySdk::LoyaltyCardTransaction](docs/LoyaltyCardTransaction.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetails](docs/LoyaltyCardTransactionDetails.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsBalance](docs/LoyaltyCardTransactionDetailsBalance.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsBalanceRelatedObject](docs/LoyaltyCardTransactionDetailsBalanceRelatedObject.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsCustomEvent](docs/LoyaltyCardTransactionDetailsCustomEvent.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsEarningRule](docs/LoyaltyCardTransactionDetailsEarningRule.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsEarningRuleSource](docs/LoyaltyCardTransactionDetailsEarningRuleSource.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsEvent](docs/LoyaltyCardTransactionDetailsEvent.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsEventSchema](docs/LoyaltyCardTransactionDetailsEventSchema.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsLoyaltyTier](docs/LoyaltyCardTransactionDetailsLoyaltyTier.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsOrder](docs/LoyaltyCardTransactionDetailsOrder.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsRedemption](docs/LoyaltyCardTransactionDetailsRedemption.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsReward](docs/LoyaltyCardTransactionDetailsReward.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsRollback](docs/LoyaltyCardTransactionDetailsRollback.md)
 - [VoucherifySdk::LoyaltyCardTransactionDetailsSegment](docs/LoyaltyCardTransactionDetailsSegment.md)
 - [VoucherifySdk::LoyaltyCardTransactionsType](docs/LoyaltyCardTransactionsType.md)
 - [VoucherifySdk::LoyaltyMember](docs/LoyaltyMember.md)
 - [VoucherifySdk::LoyaltyMemberLoyaltyCard](docs/LoyaltyMemberLoyaltyCard.md)
 - [VoucherifySdk::LoyaltyMemberPublish](docs/LoyaltyMemberPublish.md)
 - [VoucherifySdk::LoyaltyMemberRedemption](docs/LoyaltyMemberRedemption.md)
 - [VoucherifySdk::LoyaltyTier](docs/LoyaltyTier.md)
 - [VoucherifySdk::LoyaltyTierBase](docs/LoyaltyTierBase.md)
 - [VoucherifySdk::LoyaltyTierBasePoints](docs/LoyaltyTierBasePoints.md)
 - [VoucherifySdk::LoyaltyTierConfig](docs/LoyaltyTierConfig.md)
 - [VoucherifySdk::LoyaltyTierConfigPoints](docs/LoyaltyTierConfigPoints.md)
 - [VoucherifySdk::LoyaltyTierExpiration](docs/LoyaltyTierExpiration.md)
 - [VoucherifySdk::LoyaltyTierPoints](docs/LoyaltyTierPoints.md)
 - [VoucherifySdk::LoyaltyTiersExpirationAll](docs/LoyaltyTiersExpirationAll.md)
 - [VoucherifySdk::LoyaltyTiersExpirationAllExpirationDate](docs/LoyaltyTiersExpirationAllExpirationDate.md)
 - [VoucherifySdk::LoyaltyTiersExpirationAllExpirationDateRounding](docs/LoyaltyTiersExpirationAllExpirationDateRounding.md)
 - [VoucherifySdk::LoyaltyTiersExpirationAllStartDate](docs/LoyaltyTiersExpirationAllStartDate.md)
 - [VoucherifySdk::ManagementProject](docs/ManagementProject.md)
 - [VoucherifySdk::ManagementProjectApiUsageNotifications](docs/ManagementProjectApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectDefaultCodeConfig](docs/ManagementProjectDefaultCodeConfig.md)
 - [VoucherifySdk::ManagementProjectLimits](docs/ManagementProjectLimits.md)
 - [VoucherifySdk::ManagementProjectLimitsApiCallsItem](docs/ManagementProjectLimitsApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectLimitsBulkApiCallsItem](docs/ManagementProjectLimitsBulkApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectWebhooksCalloutNotifications](docs/ManagementProjectWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectWebhooksCalloutNotificationsDistributions](docs/ManagementProjectWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsBranding](docs/ManagementProjectsBranding.md)
 - [VoucherifySdk::ManagementProjectsBrandingAddress](docs/ManagementProjectsBrandingAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingBrand](docs/ManagementProjectsBrandingBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingCockpits](docs/ManagementProjectsBrandingCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingContact](docs/ManagementProjectsBrandingContact.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateRequestBody](docs/ManagementProjectsBrandingCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateRequestBodyAddress](docs/ManagementProjectsBrandingCreateRequestBodyAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateRequestBodyBrand](docs/ManagementProjectsBrandingCreateRequestBodyBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateRequestBodyCockpits](docs/ManagementProjectsBrandingCreateRequestBodyCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateRequestBodyContact](docs/ManagementProjectsBrandingCreateRequestBodyContact.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateResponseBody](docs/ManagementProjectsBrandingCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateResponseBodyAddress](docs/ManagementProjectsBrandingCreateResponseBodyAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateResponseBodyBrand](docs/ManagementProjectsBrandingCreateResponseBodyBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateResponseBodyCockpits](docs/ManagementProjectsBrandingCreateResponseBodyCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingCreateResponseBodyContact](docs/ManagementProjectsBrandingCreateResponseBodyContact.md)
 - [VoucherifySdk::ManagementProjectsBrandingGetResponseBody](docs/ManagementProjectsBrandingGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingGetResponseBodyAddress](docs/ManagementProjectsBrandingGetResponseBodyAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingGetResponseBodyBrand](docs/ManagementProjectsBrandingGetResponseBodyBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingGetResponseBodyCockpits](docs/ManagementProjectsBrandingGetResponseBodyCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingGetResponseBodyContact](docs/ManagementProjectsBrandingGetResponseBodyContact.md)
 - [VoucherifySdk::ManagementProjectsBrandingListResponseBody](docs/ManagementProjectsBrandingListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateRequestBody](docs/ManagementProjectsBrandingUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateRequestBodyAddress](docs/ManagementProjectsBrandingUpdateRequestBodyAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateRequestBodyBrand](docs/ManagementProjectsBrandingUpdateRequestBodyBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateRequestBodyCockpits](docs/ManagementProjectsBrandingUpdateRequestBodyCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateRequestBodyContact](docs/ManagementProjectsBrandingUpdateRequestBodyContact.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateResponseBody](docs/ManagementProjectsBrandingUpdateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateResponseBodyAddress](docs/ManagementProjectsBrandingUpdateResponseBodyAddress.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateResponseBodyBrand](docs/ManagementProjectsBrandingUpdateResponseBodyBrand.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateResponseBodyCockpits](docs/ManagementProjectsBrandingUpdateResponseBodyCockpits.md)
 - [VoucherifySdk::ManagementProjectsBrandingUpdateResponseBodyContact](docs/ManagementProjectsBrandingUpdateResponseBodyContact.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBody](docs/ManagementProjectsCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBodyApiUsageNotifications](docs/ManagementProjectsCreateRequestBodyApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBodyUsersItem](docs/ManagementProjectsCreateRequestBodyUsersItem.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBodyWebhooksCalloutNotifications](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBody](docs/ManagementProjectsCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyApiUsageNotifications](docs/ManagementProjectsCreateResponseBodyApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyClientSideKey](docs/ManagementProjectsCreateResponseBodyClientSideKey.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyServerSideKey](docs/ManagementProjectsCreateResponseBodyServerSideKey.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchema](docs/ManagementProjectsCustomEventSchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemaSchema](docs/ManagementProjectsCustomEventSchemaSchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasCreateRequestBody](docs/ManagementProjectsCustomEventSchemasCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasCreateRequestBodySchema](docs/ManagementProjectsCustomEventSchemasCreateRequestBodySchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasCreateRequestBodySchemaPropertiesEntry](docs/ManagementProjectsCustomEventSchemasCreateRequestBodySchemaPropertiesEntry.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasCreateResponseBody](docs/ManagementProjectsCustomEventSchemasCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasCreateResponseBodySchema](docs/ManagementProjectsCustomEventSchemasCreateResponseBodySchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasGetResponseBody](docs/ManagementProjectsCustomEventSchemasGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasGetResponseBodySchema](docs/ManagementProjectsCustomEventSchemasGetResponseBodySchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasListResponseBody](docs/ManagementProjectsCustomEventSchemasListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasUpdateRequestBody](docs/ManagementProjectsCustomEventSchemasUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasUpdateRequestBodySchema](docs/ManagementProjectsCustomEventSchemasUpdateRequestBodySchema.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasUpdateResponseBody](docs/ManagementProjectsCustomEventSchemasUpdateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsCustomEventSchemasUpdateResponseBodySchema](docs/ManagementProjectsCustomEventSchemasUpdateResponseBodySchema.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBody](docs/ManagementProjectsGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyApiUsageNotifications](docs/ManagementProjectsGetResponseBodyApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyDefaultCodeConfig](docs/ManagementProjectsGetResponseBodyDefaultCodeConfig.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyLimits](docs/ManagementProjectsGetResponseBodyLimits.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyLimitsApiCallsItem](docs/ManagementProjectsGetResponseBodyLimitsApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyLimitsBulkApiCallsItem](docs/ManagementProjectsGetResponseBodyLimitsBulkApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsListResponseBody](docs/ManagementProjectsListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchema](docs/ManagementProjectsMetadataSchema.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemaDefinition](docs/ManagementProjectsMetadataSchemaDefinition.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasCreateRequestBody](docs/ManagementProjectsMetadataSchemasCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasCreateResponseBody](docs/ManagementProjectsMetadataSchemasCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasGetResponseBody](docs/ManagementProjectsMetadataSchemasGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasListResponseBody](docs/ManagementProjectsMetadataSchemasListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasUpdateRequestBody](docs/ManagementProjectsMetadataSchemasUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsMetadataSchemasUpdateResponseBody](docs/ManagementProjectsMetadataSchemasUpdateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRules](docs/ManagementProjectsStackingRules.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesCreateRequestBody](docs/ManagementProjectsStackingRulesCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesCreateResponseBody](docs/ManagementProjectsStackingRulesCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesGetResponseBody](docs/ManagementProjectsStackingRulesGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesListResponseBody](docs/ManagementProjectsStackingRulesListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesUpdateRequestBody](docs/ManagementProjectsStackingRulesUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsStackingRulesUpdateResponseBody](docs/ManagementProjectsStackingRulesUpdateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsTemplatesCampaignsCopyCreateRequestBody](docs/ManagementProjectsTemplatesCampaignsCopyCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsTemplatesCampaignsCopyCreateResponseBody](docs/ManagementProjectsTemplatesCampaignsCopyCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsTemplatesCampaignsListResponseBody](docs/ManagementProjectsTemplatesCampaignsListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBody](docs/ManagementProjectsUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBodyApiUsageNotifications](docs/ManagementProjectsUpdateRequestBodyApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBodyDefaultCodeConfig](docs/ManagementProjectsUpdateRequestBodyDefaultCodeConfig.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBodyWebhooksCalloutNotifications](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBody](docs/ManagementProjectsUpdateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyApiUsageNotifications](docs/ManagementProjectsUpdateResponseBodyApiUsageNotifications.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyDefaultCodeConfig](docs/ManagementProjectsUpdateResponseBodyDefaultCodeConfig.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyLimits](docs/ManagementProjectsUpdateResponseBodyLimits.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyLimitsApiCallsItem](docs/ManagementProjectsUpdateResponseBodyLimitsApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyLimitsBulkApiCallsItem](docs/ManagementProjectsUpdateResponseBodyLimitsBulkApiCallsItem.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotifications.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [VoucherifySdk::ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [VoucherifySdk::ManagementProjectsUsersAssignRequestBody](docs/ManagementProjectsUsersAssignRequestBody.md)
 - [VoucherifySdk::ManagementProjectsUsersAssignResponseBody](docs/ManagementProjectsUsersAssignResponseBody.md)
 - [VoucherifySdk::ManagementProjectsUsersGetUserResponseBody](docs/ManagementProjectsUsersGetUserResponseBody.md)
 - [VoucherifySdk::ManagementProjectsUsersInviteCreateRequestBody](docs/ManagementProjectsUsersInviteCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsUsersListResponseBody](docs/ManagementProjectsUsersListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsUsersUpdateRoleRequestBody](docs/ManagementProjectsUsersUpdateRoleRequestBody.md)
 - [VoucherifySdk::ManagementProjectsUsersUpdateRoleResponseBody](docs/ManagementProjectsUsersUpdateRoleResponseBody.md)
 - [VoucherifySdk::ManagementProjectsWebhook](docs/ManagementProjectsWebhook.md)
 - [VoucherifySdk::ManagementProjectsWebhooksCreateRequestBody](docs/ManagementProjectsWebhooksCreateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsWebhooksCreateResponseBody](docs/ManagementProjectsWebhooksCreateResponseBody.md)
 - [VoucherifySdk::ManagementProjectsWebhooksGetResponseBody](docs/ManagementProjectsWebhooksGetResponseBody.md)
 - [VoucherifySdk::ManagementProjectsWebhooksListResponseBody](docs/ManagementProjectsWebhooksListResponseBody.md)
 - [VoucherifySdk::ManagementProjectsWebhooksUpdateRequestBody](docs/ManagementProjectsWebhooksUpdateRequestBody.md)
 - [VoucherifySdk::ManagementProjectsWebhooksUpdateResponseBody](docs/ManagementProjectsWebhooksUpdateResponseBody.md)
 - [VoucherifySdk::MappingPoints](docs/MappingPoints.md)
 - [VoucherifySdk::MemberActivity](docs/MemberActivity.md)
 - [VoucherifySdk::MetadataSchemaDefinitionDeprecated](docs/MetadataSchemaDefinitionDeprecated.md)
 - [VoucherifySdk::MetadataSchemaDeprecated](docs/MetadataSchemaDeprecated.md)
 - [VoucherifySdk::MetadataSchemasGetResponseBody](docs/MetadataSchemasGetResponseBody.md)
 - [VoucherifySdk::MetadataSchemasListResponseBody](docs/MetadataSchemasListResponseBody.md)
 - [VoucherifySdk::Order](docs/Order.md)
 - [VoucherifySdk::OrderCalculated](docs/OrderCalculated.md)
 - [VoucherifySdk::OrderCalculatedItem](docs/OrderCalculatedItem.md)
 - [VoucherifySdk::OrderCalculatedItemProduct](docs/OrderCalculatedItemProduct.md)
 - [VoucherifySdk::OrderCalculatedItemSku](docs/OrderCalculatedItemSku.md)
 - [VoucherifySdk::OrderItem](docs/OrderItem.md)
 - [VoucherifySdk::OrderItemProduct](docs/OrderItemProduct.md)
 - [VoucherifySdk::OrderItemSku](docs/OrderItemSku.md)
 - [VoucherifySdk::OrderRedemptionsEntry](docs/OrderRedemptionsEntry.md)
 - [VoucherifySdk::OrdersCreateRequestBody](docs/OrdersCreateRequestBody.md)
 - [VoucherifySdk::OrdersCreateResponseBody](docs/OrdersCreateResponseBody.md)
 - [VoucherifySdk::OrdersExportCreateRequestBody](docs/OrdersExportCreateRequestBody.md)
 - [VoucherifySdk::OrdersExportCreateRequestBodyParameters](docs/OrdersExportCreateRequestBodyParameters.md)
 - [VoucherifySdk::OrdersExportCreateResponseBody](docs/OrdersExportCreateResponseBody.md)
 - [VoucherifySdk::OrdersExportCreateResponseBodyParameters](docs/OrdersExportCreateResponseBodyParameters.md)
 - [VoucherifySdk::OrdersGetResponseBody](docs/OrdersGetResponseBody.md)
 - [VoucherifySdk::OrdersImportCreateRequestBodyItem](docs/OrdersImportCreateRequestBodyItem.md)
 - [VoucherifySdk::OrdersImportCreateResponseBody](docs/OrdersImportCreateResponseBody.md)
 - [VoucherifySdk::OrdersListResponseBody](docs/OrdersListResponseBody.md)
 - [VoucherifySdk::OrdersUpdateRequestBody](docs/OrdersUpdateRequestBody.md)
 - [VoucherifySdk::OrdersUpdateResponseBody](docs/OrdersUpdateResponseBody.md)
 - [VoucherifySdk::ParameterActivityCategory](docs/ParameterActivityCategory.md)
 - [VoucherifySdk::ParameterCampaignType](docs/ParameterCampaignType.md)
 - [VoucherifySdk::ParameterCreatedBeforeAfter](docs/ParameterCreatedBeforeAfter.md)
 - [VoucherifySdk::ParameterExpandListCampaigns](docs/ParameterExpandListCampaigns.md)
 - [VoucherifySdk::ParameterFiltersListBin](docs/ParameterFiltersListBin.md)
 - [VoucherifySdk::ParameterFiltersListBinId](docs/ParameterFiltersListBinId.md)
 - [VoucherifySdk::ParameterFiltersListBinResourceId](docs/ParameterFiltersListBinResourceId.md)
 - [VoucherifySdk::ParameterFiltersListBinResourceName](docs/ParameterFiltersListBinResourceName.md)
 - [VoucherifySdk::ParameterFiltersListBinResourceType](docs/ParameterFiltersListBinResourceType.md)
 - [VoucherifySdk::ParameterFiltersListBinResourceTypeConditions](docs/ParameterFiltersListBinResourceTypeConditions.md)
 - [VoucherifySdk::ParameterFiltersListCampaigns](docs/ParameterFiltersListCampaigns.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsCampaignStatus](docs/ParameterFiltersListCampaignsCampaignStatus.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsCampaignStatusConditions](docs/ParameterFiltersListCampaignsCampaignStatusConditions.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsCategories](docs/ParameterFiltersListCampaignsCategories.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsCategoryIds](docs/ParameterFiltersListCampaignsCategoryIds.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsIsReferralCode](docs/ParameterFiltersListCampaignsIsReferralCode.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsValidityTimeframe](docs/ParameterFiltersListCampaignsValidityTimeframe.md)
 - [VoucherifySdk::ParameterFiltersListCampaignsVoucherType](docs/ParameterFiltersListCampaignsVoucherType.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemables](docs/ParameterFiltersListCustomerRedeemables.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesCampaignId](docs/ParameterFiltersListCustomerRedeemablesCampaignId.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesCampaignType](docs/ParameterFiltersListCustomerRedeemablesCampaignType.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesCampaignTypeConditions](docs/ParameterFiltersListCustomerRedeemablesCampaignTypeConditions.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesCreatedAt](docs/ParameterFiltersListCustomerRedeemablesCreatedAt.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesHolderRole](docs/ParameterFiltersListCustomerRedeemablesHolderRole.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesHolderRoleConditions](docs/ParameterFiltersListCustomerRedeemablesHolderRoleConditions.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesId](docs/ParameterFiltersListCustomerRedeemablesId.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesRedeemableId](docs/ParameterFiltersListCustomerRedeemablesRedeemableId.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesRedeemableObject](docs/ParameterFiltersListCustomerRedeemablesRedeemableObject.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesRedeemableObjectConditions](docs/ParameterFiltersListCustomerRedeemablesRedeemableObjectConditions.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesVoucherType](docs/ParameterFiltersListCustomerRedeemablesVoucherType.md)
 - [VoucherifySdk::ParameterFiltersListCustomerRedeemablesVoucherTypeConditions](docs/ParameterFiltersListCustomerRedeemablesVoucherTypeConditions.md)
 - [VoucherifySdk::ParameterFiltersListLocations](docs/ParameterFiltersListLocations.md)
 - [VoucherifySdk::ParameterFiltersListLocationsCreatedAt](docs/ParameterFiltersListLocationsCreatedAt.md)
 - [VoucherifySdk::ParameterFiltersListLocationsName](docs/ParameterFiltersListLocationsName.md)
 - [VoucherifySdk::ParameterFiltersListLocationsUpdatedAt](docs/ParameterFiltersListLocationsUpdatedAt.md)
 - [VoucherifySdk::ParameterFiltersListPublications](docs/ParameterFiltersListPublications.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsCampaignName](docs/ParameterFiltersListPublicationsCampaignName.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsCustomerId](docs/ParameterFiltersListPublicationsCustomerId.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsFailureCode](docs/ParameterFiltersListPublicationsFailureCode.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsIsReferralCode](docs/ParameterFiltersListPublicationsIsReferralCode.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsParentObjectId](docs/ParameterFiltersListPublicationsParentObjectId.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsRelatedObjectId](docs/ParameterFiltersListPublicationsRelatedObjectId.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsResult](docs/ParameterFiltersListPublicationsResult.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsSourceId](docs/ParameterFiltersListPublicationsSourceId.md)
 - [VoucherifySdk::ParameterFiltersListPublicationsVoucherType](docs/ParameterFiltersListPublicationsVoucherType.md)
 - [VoucherifySdk::ParameterFiltersListRedemptions](docs/ParameterFiltersListRedemptions.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsCampaignName](docs/ParameterFiltersListRedemptionsCampaignName.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsCustomerId](docs/ParameterFiltersListRedemptionsCustomerId.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsFailureCode](docs/ParameterFiltersListRedemptionsFailureCode.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsObject](docs/ParameterFiltersListRedemptionsObject.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsParentRedemptionId](docs/ParameterFiltersListRedemptionsParentRedemptionId.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsRelatedObjectId](docs/ParameterFiltersListRedemptionsRelatedObjectId.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsRelatedObjectParentId](docs/ParameterFiltersListRedemptionsRelatedObjectParentId.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsResult](docs/ParameterFiltersListRedemptionsResult.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsUserLogin](docs/ParameterFiltersListRedemptionsUserLogin.md)
 - [VoucherifySdk::ParameterFiltersListRedemptionsVoucherCode](docs/ParameterFiltersListRedemptionsVoucherCode.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHolders](docs/ParameterFiltersListReferralsRedeemableHolders.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHoldersCreatedAt](docs/ParameterFiltersListReferralsRedeemableHoldersCreatedAt.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHoldersCustomerId](docs/ParameterFiltersListReferralsRedeemableHoldersCustomerId.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHoldersHolderRole](docs/ParameterFiltersListReferralsRedeemableHoldersHolderRole.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHoldersHolderRoleConditions](docs/ParameterFiltersListReferralsRedeemableHoldersHolderRoleConditions.md)
 - [VoucherifySdk::ParameterFiltersListReferralsRedeemableHoldersId](docs/ParameterFiltersListReferralsRedeemableHoldersId.md)
 - [VoucherifySdk::ParameterFiltersListTemplates](docs/ParameterFiltersListTemplates.md)
 - [VoucherifySdk::ParameterFiltersListTemplatesCampaignType](docs/ParameterFiltersListTemplatesCampaignType.md)
 - [VoucherifySdk::ParameterFiltersListTemplatesCampaignTypeConditions](docs/ParameterFiltersListTemplatesCampaignTypeConditions.md)
 - [VoucherifySdk::ParameterFiltersListTemplatesId](docs/ParameterFiltersListTemplatesId.md)
 - [VoucherifySdk::ParameterFiltersListTemplatesName](docs/ParameterFiltersListTemplatesName.md)
 - [VoucherifySdk::ParameterOrder](docs/ParameterOrder.md)
 - [VoucherifySdk::ParameterOrderCreatedAt](docs/ParameterOrderCreatedAt.md)
 - [VoucherifySdk::ParameterOrderListAllPromotionStacks](docs/ParameterOrderListAllPromotionStacks.md)
 - [VoucherifySdk::ParameterOrderListBin](docs/ParameterOrderListBin.md)
 - [VoucherifySdk::ParameterOrderListCampaigns](docs/ParameterOrderListCampaigns.md)
 - [VoucherifySdk::ParameterOrderListCustomers](docs/ParameterOrderListCustomers.md)
 - [VoucherifySdk::ParameterOrderListEarningRules](docs/ParameterOrderListEarningRules.md)
 - [VoucherifySdk::ParameterOrderListExports](docs/ParameterOrderListExports.md)
 - [VoucherifySdk::ParameterOrderListLocations](docs/ParameterOrderListLocations.md)
 - [VoucherifySdk::ParameterOrderListLoyaltyTiers](docs/ParameterOrderListLoyaltyTiers.md)
 - [VoucherifySdk::ParameterOrderListOrders](docs/ParameterOrderListOrders.md)
 - [VoucherifySdk::ParameterOrderListPromotionTiers](docs/ParameterOrderListPromotionTiers.md)
 - [VoucherifySdk::ParameterOrderListPromotionTiersClientSide](docs/ParameterOrderListPromotionTiersClientSide.md)
 - [VoucherifySdk::ParameterOrderListPublications](docs/ParameterOrderListPublications.md)
 - [VoucherifySdk::ParameterOrderListRedeemables](docs/ParameterOrderListRedeemables.md)
 - [VoucherifySdk::ParameterOrderListRedemptions](docs/ParameterOrderListRedemptions.md)
 - [VoucherifySdk::ParameterOrderListTransactions](docs/ParameterOrderListTransactions.md)
 - [VoucherifySdk::ParameterOrderListValidationRuleAssignments](docs/ParameterOrderListValidationRuleAssignments.md)
 - [VoucherifySdk::ParameterOrderListValidationRules](docs/ParameterOrderListValidationRules.md)
 - [VoucherifySdk::ParameterOrderVouchers](docs/ParameterOrderVouchers.md)
 - [VoucherifySdk::ParameterResultListPublications](docs/ParameterResultListPublications.md)
 - [VoucherifySdk::ParameterTemplatesList](docs/ParameterTemplatesList.md)
 - [VoucherifySdk::ParameterUpdatedBeforeAfter](docs/ParameterUpdatedBeforeAfter.md)
 - [VoucherifySdk::ParameterVoucherTypeListPublications](docs/ParameterVoucherTypeListPublications.md)
 - [VoucherifySdk::PointsExpirationTypes](docs/PointsExpirationTypes.md)
 - [VoucherifySdk::Product](docs/Product.md)
 - [VoucherifySdk::ProductCollectionsCreateRequestBody](docs/ProductCollectionsCreateRequestBody.md)
 - [VoucherifySdk::ProductCollectionsCreateRequestBodyProductsItem](docs/ProductCollectionsCreateRequestBodyProductsItem.md)
 - [VoucherifySdk::ProductCollectionsCreateResponseBody](docs/ProductCollectionsCreateResponseBody.md)
 - [VoucherifySdk::ProductCollectionsCreateResponseBodyProductsItem](docs/ProductCollectionsCreateResponseBodyProductsItem.md)
 - [VoucherifySdk::ProductCollectionsGetResponseBody](docs/ProductCollectionsGetResponseBody.md)
 - [VoucherifySdk::ProductCollectionsGetResponseBodyProductsItem](docs/ProductCollectionsGetResponseBodyProductsItem.md)
 - [VoucherifySdk::ProductCollectionsItem](docs/ProductCollectionsItem.md)
 - [VoucherifySdk::ProductCollectionsItemProductsItem](docs/ProductCollectionsItemProductsItem.md)
 - [VoucherifySdk::ProductCollectionsListResponseBody](docs/ProductCollectionsListResponseBody.md)
 - [VoucherifySdk::ProductCollectionsProductsListResponseBody](docs/ProductCollectionsProductsListResponseBody.md)
 - [VoucherifySdk::ProductCollectionsProductsListResponseBodyDataItem](docs/ProductCollectionsProductsListResponseBodyDataItem.md)
 - [VoucherifySdk::ProductWithoutSkus](docs/ProductWithoutSkus.md)
 - [VoucherifySdk::ProductsCreateRequestBody](docs/ProductsCreateRequestBody.md)
 - [VoucherifySdk::ProductsCreateResponseBody](docs/ProductsCreateResponseBody.md)
 - [VoucherifySdk::ProductsGetResponseBody](docs/ProductsGetResponseBody.md)
 - [VoucherifySdk::ProductsImportCsvCreateResponseBody](docs/ProductsImportCsvCreateResponseBody.md)
 - [VoucherifySdk::ProductsListResponseBody](docs/ProductsListResponseBody.md)
 - [VoucherifySdk::ProductsMetadataUpdateInBulkRequestBody](docs/ProductsMetadataUpdateInBulkRequestBody.md)
 - [VoucherifySdk::ProductsMetadataUpdateInBulkResponseBody](docs/ProductsMetadataUpdateInBulkResponseBody.md)
 - [VoucherifySdk::ProductsSkusCreateRequestBody](docs/ProductsSkusCreateRequestBody.md)
 - [VoucherifySdk::ProductsSkusCreateResponseBody](docs/ProductsSkusCreateResponseBody.md)
 - [VoucherifySdk::ProductsSkusListResponseBody](docs/ProductsSkusListResponseBody.md)
 - [VoucherifySdk::ProductsSkusUpdateRequestBody](docs/ProductsSkusUpdateRequestBody.md)
 - [VoucherifySdk::ProductsSkusUpdateResponseBody](docs/ProductsSkusUpdateResponseBody.md)
 - [VoucherifySdk::ProductsUpdateInBulkRequestBody](docs/ProductsUpdateInBulkRequestBody.md)
 - [VoucherifySdk::ProductsUpdateInBulkResponseBody](docs/ProductsUpdateInBulkResponseBody.md)
 - [VoucherifySdk::ProductsUpdateRequestBody](docs/ProductsUpdateRequestBody.md)
 - [VoucherifySdk::ProductsUpdateResponseBody](docs/ProductsUpdateResponseBody.md)
 - [VoucherifySdk::PromotionStack](docs/PromotionStack.md)
 - [VoucherifySdk::PromotionStackBase](docs/PromotionStackBase.md)
 - [VoucherifySdk::PromotionStackBaseTiers](docs/PromotionStackBaseTiers.md)
 - [VoucherifySdk::PromotionStackTiers](docs/PromotionStackTiers.md)
 - [VoucherifySdk::PromotionTier](docs/PromotionTier.md)
 - [VoucherifySdk::PromotionTierAction](docs/PromotionTierAction.md)
 - [VoucherifySdk::PromotionTierCampaign](docs/PromotionTierCampaign.md)
 - [VoucherifySdk::PromotionTierCreateParams](docs/PromotionTierCreateParams.md)
 - [VoucherifySdk::PromotionTierCreateParamsAction](docs/PromotionTierCreateParamsAction.md)
 - [VoucherifySdk::PromotionTierSummary](docs/PromotionTierSummary.md)
 - [VoucherifySdk::PromotionTierSummaryOrders](docs/PromotionTierSummaryOrders.md)
 - [VoucherifySdk::PromotionTierSummaryRedemptions](docs/PromotionTierSummaryRedemptions.md)
 - [VoucherifySdk::PromotionTiersList](docs/PromotionTiersList.md)
 - [VoucherifySdk::PromotionsStacksCreateRequestBody](docs/PromotionsStacksCreateRequestBody.md)
 - [VoucherifySdk::PromotionsStacksCreateRequestBodyTiers](docs/PromotionsStacksCreateRequestBodyTiers.md)
 - [VoucherifySdk::PromotionsStacksCreateResponseBody](docs/PromotionsStacksCreateResponseBody.md)
 - [VoucherifySdk::PromotionsStacksCreateResponseBodyTiers](docs/PromotionsStacksCreateResponseBodyTiers.md)
 - [VoucherifySdk::PromotionsStacksGetResponseBody](docs/PromotionsStacksGetResponseBody.md)
 - [VoucherifySdk::PromotionsStacksGetResponseBodyTiers](docs/PromotionsStacksGetResponseBodyTiers.md)
 - [VoucherifySdk::PromotionsStacksListResponseBody](docs/PromotionsStacksListResponseBody.md)
 - [VoucherifySdk::PromotionsStacksUpdateRequestBody](docs/PromotionsStacksUpdateRequestBody.md)
 - [VoucherifySdk::PromotionsStacksUpdateRequestBodyTiers](docs/PromotionsStacksUpdateRequestBodyTiers.md)
 - [VoucherifySdk::PromotionsStacksUpdateResponseBody](docs/PromotionsStacksUpdateResponseBody.md)
 - [VoucherifySdk::PromotionsStacksUpdateResponseBodyTiers](docs/PromotionsStacksUpdateResponseBodyTiers.md)
 - [VoucherifySdk::PromotionsTiersCreateRequestBody](docs/PromotionsTiersCreateRequestBody.md)
 - [VoucherifySdk::PromotionsTiersCreateRequestBodyAction](docs/PromotionsTiersCreateRequestBodyAction.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBody](docs/PromotionsTiersCreateResponseBody.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBodyAction](docs/PromotionsTiersCreateResponseBodyAction.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBodyCampaign](docs/PromotionsTiersCreateResponseBodyCampaign.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBodySummary](docs/PromotionsTiersCreateResponseBodySummary.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBodySummaryOrders](docs/PromotionsTiersCreateResponseBodySummaryOrders.md)
 - [VoucherifySdk::PromotionsTiersCreateResponseBodySummaryRedemptions](docs/PromotionsTiersCreateResponseBodySummaryRedemptions.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBody](docs/PromotionsTiersDisableResponseBody.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBodyAction](docs/PromotionsTiersDisableResponseBodyAction.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBodyCampaign](docs/PromotionsTiersDisableResponseBodyCampaign.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBodySummary](docs/PromotionsTiersDisableResponseBodySummary.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBodySummaryOrders](docs/PromotionsTiersDisableResponseBodySummaryOrders.md)
 - [VoucherifySdk::PromotionsTiersDisableResponseBodySummaryRedemptions](docs/PromotionsTiersDisableResponseBodySummaryRedemptions.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBody](docs/PromotionsTiersEnableResponseBody.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBodyAction](docs/PromotionsTiersEnableResponseBodyAction.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBodyCampaign](docs/PromotionsTiersEnableResponseBodyCampaign.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBodySummary](docs/PromotionsTiersEnableResponseBodySummary.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBodySummaryOrders](docs/PromotionsTiersEnableResponseBodySummaryOrders.md)
 - [VoucherifySdk::PromotionsTiersEnableResponseBodySummaryRedemptions](docs/PromotionsTiersEnableResponseBodySummaryRedemptions.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBody](docs/PromotionsTiersGetResponseBody.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBodyAction](docs/PromotionsTiersGetResponseBodyAction.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBodyCampaign](docs/PromotionsTiersGetResponseBodyCampaign.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBodySummary](docs/PromotionsTiersGetResponseBodySummary.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBodySummaryOrders](docs/PromotionsTiersGetResponseBodySummaryOrders.md)
 - [VoucherifySdk::PromotionsTiersGetResponseBodySummaryRedemptions](docs/PromotionsTiersGetResponseBodySummaryRedemptions.md)
 - [VoucherifySdk::PromotionsTiersListResponseBody](docs/PromotionsTiersListResponseBody.md)
 - [VoucherifySdk::PromotionsTiersUpdateRequestBody](docs/PromotionsTiersUpdateRequestBody.md)
 - [VoucherifySdk::PromotionsTiersUpdateRequestBodyAction](docs/PromotionsTiersUpdateRequestBodyAction.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBody](docs/PromotionsTiersUpdateResponseBody.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBodyAction](docs/PromotionsTiersUpdateResponseBodyAction.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBodyCampaign](docs/PromotionsTiersUpdateResponseBodyCampaign.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBodySummary](docs/PromotionsTiersUpdateResponseBodySummary.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBodySummaryOrders](docs/PromotionsTiersUpdateResponseBodySummaryOrders.md)
 - [VoucherifySdk::PromotionsTiersUpdateResponseBodySummaryRedemptions](docs/PromotionsTiersUpdateResponseBodySummaryRedemptions.md)
 - [VoucherifySdk::PublicationsCreateRequestBody](docs/PublicationsCreateRequestBody.md)
 - [VoucherifySdk::PublicationsCreateResponseBody](docs/PublicationsCreateResponseBody.md)
 - [VoucherifySdk::PublicationsListResponseBody](docs/PublicationsListResponseBody.md)
 - [VoucherifySdk::PublicationsListResponseBodyPublicationsItem](docs/PublicationsListResponseBodyPublicationsItem.md)
 - [VoucherifySdk::PublicationsListResponseBodyPublicationsItemMetadata](docs/PublicationsListResponseBodyPublicationsItemMetadata.md)
 - [VoucherifySdk::QualificationsCheckEligibilityRequestBody](docs/QualificationsCheckEligibilityRequestBody.md)
 - [VoucherifySdk::QualificationsCheckEligibilityResponseBody](docs/QualificationsCheckEligibilityResponseBody.md)
 - [VoucherifySdk::QualificationsFieldConditions](docs/QualificationsFieldConditions.md)
 - [VoucherifySdk::QualificationsFiltersCondition](docs/QualificationsFiltersCondition.md)
 - [VoucherifySdk::QualificationsOption](docs/QualificationsOption.md)
 - [VoucherifySdk::QualificationsOptionFilters](docs/QualificationsOptionFilters.md)
 - [VoucherifySdk::QualificationsOptionFiltersCampaignType](docs/QualificationsOptionFiltersCampaignType.md)
 - [VoucherifySdk::QualificationsOptionFiltersCampaignTypeConditions](docs/QualificationsOptionFiltersCampaignTypeConditions.md)
 - [VoucherifySdk::QualificationsOptionFiltersHolderRole](docs/QualificationsOptionFiltersHolderRole.md)
 - [VoucherifySdk::QualificationsOptionFiltersHolderRoleConditions](docs/QualificationsOptionFiltersHolderRoleConditions.md)
 - [VoucherifySdk::QualificationsOptionFiltersResourceType](docs/QualificationsOptionFiltersResourceType.md)
 - [VoucherifySdk::QualificationsOptionFiltersResourceTypeConditions](docs/QualificationsOptionFiltersResourceTypeConditions.md)
 - [VoucherifySdk::QualificationsRedeemable](docs/QualificationsRedeemable.md)
 - [VoucherifySdk::QualificationsRedeemableBase](docs/QualificationsRedeemableBase.md)
 - [VoucherifySdk::QualificationsRedeemables](docs/QualificationsRedeemables.md)
 - [VoucherifySdk::RedeemableGift](docs/RedeemableGift.md)
 - [VoucherifySdk::RedeemableHolder](docs/RedeemableHolder.md)
 - [VoucherifySdk::RedeemableLoyaltyCard](docs/RedeemableLoyaltyCard.md)
 - [VoucherifySdk::RedeemableResult](docs/RedeemableResult.md)
 - [VoucherifySdk::RedeemableVoucher](docs/RedeemableVoucher.md)
 - [VoucherifySdk::RedeemableVoucherGift](docs/RedeemableVoucherGift.md)
 - [VoucherifySdk::RedeemableVoucherLoyaltyCard](docs/RedeemableVoucherLoyaltyCard.md)
 - [VoucherifySdk::RedeemableVoucherPublish](docs/RedeemableVoucherPublish.md)
 - [VoucherifySdk::RedeemableVoucherRedemption](docs/RedeemableVoucherRedemption.md)
 - [VoucherifySdk::Redemption](docs/Redemption.md)
 - [VoucherifySdk::RedemptionChannel](docs/RedemptionChannel.md)
 - [VoucherifySdk::RedemptionEntry](docs/RedemptionEntry.md)
 - [VoucherifySdk::RedemptionEntryChannel](docs/RedemptionEntryChannel.md)
 - [VoucherifySdk::RedemptionEntryCustomer](docs/RedemptionEntryCustomer.md)
 - [VoucherifySdk::RedemptionEntryGift](docs/RedemptionEntryGift.md)
 - [VoucherifySdk::RedemptionEntryLoyaltyCard](docs/RedemptionEntryLoyaltyCard.md)
 - [VoucherifySdk::RedemptionEntryOrder](docs/RedemptionEntryOrder.md)
 - [VoucherifySdk::RedemptionEntryOrderCustomer](docs/RedemptionEntryOrderCustomer.md)
 - [VoucherifySdk::RedemptionEntryOrderReferrer](docs/RedemptionEntryOrderReferrer.md)
 - [VoucherifySdk::RedemptionEntryPromotionTier](docs/RedemptionEntryPromotionTier.md)
 - [VoucherifySdk::RedemptionEntryPromotionTierAction](docs/RedemptionEntryPromotionTierAction.md)
 - [VoucherifySdk::RedemptionEntryPromotionTierCampaign](docs/RedemptionEntryPromotionTierCampaign.md)
 - [VoucherifySdk::RedemptionEntryPromotionTierSummary](docs/RedemptionEntryPromotionTierSummary.md)
 - [VoucherifySdk::RedemptionEntryPromotionTierSummaryOrders](docs/RedemptionEntryPromotionTierSummaryOrders.md)
 - [VoucherifySdk::RedemptionEntryPromotionTierSummaryRedemptions](docs/RedemptionEntryPromotionTierSummaryRedemptions.md)
 - [VoucherifySdk::RedemptionEntryRelatedRedemptions](docs/RedemptionEntryRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionEntryRelatedRedemptionsRedemptionsItem](docs/RedemptionEntryRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionEntryRelatedRedemptionsRollbacksItem](docs/RedemptionEntryRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionEntryVoucher](docs/RedemptionEntryVoucher.md)
 - [VoucherifySdk::RedemptionEntryVoucherGift](docs/RedemptionEntryVoucherGift.md)
 - [VoucherifySdk::RedemptionEntryVoucherLoyaltyCard](docs/RedemptionEntryVoucherLoyaltyCard.md)
 - [VoucherifySdk::RedemptionEntryVoucherPublish](docs/RedemptionEntryVoucherPublish.md)
 - [VoucherifySdk::RedemptionEntryVoucherRedemption](docs/RedemptionEntryVoucherRedemption.md)
 - [VoucherifySdk::RedemptionGift](docs/RedemptionGift.md)
 - [VoucherifySdk::RedemptionLoyaltyCard](docs/RedemptionLoyaltyCard.md)
 - [VoucherifySdk::RedemptionRelatedRedemptions](docs/RedemptionRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionRelatedRedemptionsRedemptionsItem](docs/RedemptionRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionRelatedRedemptionsRollbacksItem](docs/RedemptionRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionRewardResult](docs/RedemptionRewardResult.md)
 - [VoucherifySdk::RedemptionRewardResultParameters](docs/RedemptionRewardResultParameters.md)
 - [VoucherifySdk::RedemptionRewardResultParametersCampaign](docs/RedemptionRewardResultParametersCampaign.md)
 - [VoucherifySdk::RedemptionRewardResultParametersCoin](docs/RedemptionRewardResultParametersCoin.md)
 - [VoucherifySdk::RedemptionRewardResultParametersProduct](docs/RedemptionRewardResultParametersProduct.md)
 - [VoucherifySdk::RedemptionRollback](docs/RedemptionRollback.md)
 - [VoucherifySdk::RedemptionRollbackChannel](docs/RedemptionRollbackChannel.md)
 - [VoucherifySdk::RedemptionRollbackGift](docs/RedemptionRollbackGift.md)
 - [VoucherifySdk::RedemptionRollbackLoyaltyCard](docs/RedemptionRollbackLoyaltyCard.md)
 - [VoucherifySdk::RedemptionRollbackRelatedRedemptions](docs/RedemptionRollbackRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionRollbackRelatedRedemptionsRedemptionsItem](docs/RedemptionRollbackRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionRollbackRelatedRedemptionsRollbacksItem](docs/RedemptionRollbackRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionVoucher](docs/RedemptionVoucher.md)
 - [VoucherifySdk::RedemptionVoucherGift](docs/RedemptionVoucherGift.md)
 - [VoucherifySdk::RedemptionVoucherLoyaltyCard](docs/RedemptionVoucherLoyaltyCard.md)
 - [VoucherifySdk::RedemptionVoucherPublish](docs/RedemptionVoucherPublish.md)
 - [VoucherifySdk::RedemptionVoucherRedemption](docs/RedemptionVoucherRedemption.md)
 - [VoucherifySdk::RedemptionsGetResponseBody](docs/RedemptionsGetResponseBody.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyChannel](docs/RedemptionsGetResponseBodyChannel.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyCustomer](docs/RedemptionsGetResponseBodyCustomer.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyGift](docs/RedemptionsGetResponseBodyGift.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyLoyaltyCard](docs/RedemptionsGetResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyOrder](docs/RedemptionsGetResponseBodyOrder.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyOrderCustomer](docs/RedemptionsGetResponseBodyOrderCustomer.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyOrderReferrer](docs/RedemptionsGetResponseBodyOrderReferrer.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTier](docs/RedemptionsGetResponseBodyPromotionTier.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTierAction](docs/RedemptionsGetResponseBodyPromotionTierAction.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTierCampaign](docs/RedemptionsGetResponseBodyPromotionTierCampaign.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTierSummary](docs/RedemptionsGetResponseBodyPromotionTierSummary.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTierSummaryOrders](docs/RedemptionsGetResponseBodyPromotionTierSummaryOrders.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyPromotionTierSummaryRedemptions](docs/RedemptionsGetResponseBodyPromotionTierSummaryRedemptions.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyRelatedRedemptions](docs/RedemptionsGetResponseBodyRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyRelatedRedemptionsRedemptionsItem](docs/RedemptionsGetResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyRelatedRedemptionsRollbacksItem](docs/RedemptionsGetResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyVoucher](docs/RedemptionsGetResponseBodyVoucher.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyVoucherGift](docs/RedemptionsGetResponseBodyVoucherGift.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyVoucherLoyaltyCard](docs/RedemptionsGetResponseBodyVoucherLoyaltyCard.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyVoucherPublish](docs/RedemptionsGetResponseBodyVoucherPublish.md)
 - [VoucherifySdk::RedemptionsGetResponseBodyVoucherRedemption](docs/RedemptionsGetResponseBodyVoucherRedemption.md)
 - [VoucherifySdk::RedemptionsListResponseBody](docs/RedemptionsListResponseBody.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItem](docs/RedemptionsListResponseBodyRedemptionsItem.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemChannel](docs/RedemptionsListResponseBodyRedemptionsItemChannel.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemCustomer](docs/RedemptionsListResponseBodyRedemptionsItemCustomer.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemGift](docs/RedemptionsListResponseBodyRedemptionsItemGift.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemLoyaltyCard](docs/RedemptionsListResponseBodyRedemptionsItemLoyaltyCard.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemOrder](docs/RedemptionsListResponseBodyRedemptionsItemOrder.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemOrderCustomer](docs/RedemptionsListResponseBodyRedemptionsItemOrderCustomer.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemOrderReferrer](docs/RedemptionsListResponseBodyRedemptionsItemOrderReferrer.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTier](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTier.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTierAction](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierAction.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTierCampaign](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierCampaign.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTierSummary](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummary.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryOrders](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryOrders.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryRedemptions](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryRedemptions.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemRelatedRedemptions](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRedemptionsItem](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRollbacksItem](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemVoucher](docs/RedemptionsListResponseBodyRedemptionsItemVoucher.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemVoucherGift](docs/RedemptionsListResponseBodyRedemptionsItemVoucherGift.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemVoucherLoyaltyCard](docs/RedemptionsListResponseBodyRedemptionsItemVoucherLoyaltyCard.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemVoucherPublish](docs/RedemptionsListResponseBodyRedemptionsItemVoucherPublish.md)
 - [VoucherifySdk::RedemptionsListResponseBodyRedemptionsItemVoucherRedemption](docs/RedemptionsListResponseBodyRedemptionsItemVoucherRedemption.md)
 - [VoucherifySdk::RedemptionsRedeemRequestBody](docs/RedemptionsRedeemRequestBody.md)
 - [VoucherifySdk::RedemptionsRedeemRequestBodyOptions](docs/RedemptionsRedeemRequestBodyOptions.md)
 - [VoucherifySdk::RedemptionsRedeemRequestBodyRedeemablesItem](docs/RedemptionsRedeemRequestBodyRedeemablesItem.md)
 - [VoucherifySdk::RedemptionsRedeemRequestBodyRedeemablesItemGift](docs/RedemptionsRedeemRequestBodyRedeemablesItemGift.md)
 - [VoucherifySdk::RedemptionsRedeemRequestBodyRedeemablesItemReward](docs/RedemptionsRedeemRequestBodyRedeemablesItemReward.md)
 - [VoucherifySdk::RedemptionsRedeemResponseBody](docs/RedemptionsRedeemResponseBody.md)
 - [VoucherifySdk::RedemptionsRollbackCreateRequestBody](docs/RedemptionsRollbackCreateRequestBody.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBody](docs/RedemptionsRollbackCreateResponseBody.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyChannel](docs/RedemptionsRollbackCreateResponseBodyChannel.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyGift](docs/RedemptionsRollbackCreateResponseBodyGift.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyLoyaltyCard](docs/RedemptionsRollbackCreateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyRelatedRedemptions](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptions.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRedemptionsItem](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [VoucherifySdk::RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRollbacksItem](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [VoucherifySdk::RedemptionsRollbacksCreateRequestBody](docs/RedemptionsRollbacksCreateRequestBody.md)
 - [VoucherifySdk::RedemptionsRollbacksCreateResponseBody](docs/RedemptionsRollbacksCreateResponseBody.md)
 - [VoucherifySdk::ReferralProgram](docs/ReferralProgram.md)
 - [VoucherifySdk::ReferralProgramCustomEvent](docs/ReferralProgramCustomEvent.md)
 - [VoucherifySdk::ReferralProgramRefereeReward](docs/ReferralProgramRefereeReward.md)
 - [VoucherifySdk::ReferralProgramRefereeRewardRelatedObjectParent](docs/ReferralProgramRefereeRewardRelatedObjectParent.md)
 - [VoucherifySdk::ReferralsMembersHoldersCreateInBulkRequestBody](docs/ReferralsMembersHoldersCreateInBulkRequestBody.md)
 - [VoucherifySdk::ReferralsMembersHoldersCreateInBulkResponseBody](docs/ReferralsMembersHoldersCreateInBulkResponseBody.md)
 - [VoucherifySdk::ReferralsMembersHoldersListResponseBody](docs/ReferralsMembersHoldersListResponseBody.md)
 - [VoucherifySdk::Referrer](docs/Referrer.md)
 - [VoucherifySdk::ReferrerAddress](docs/ReferrerAddress.md)
 - [VoucherifySdk::ReferrerId](docs/ReferrerId.md)
 - [VoucherifySdk::ResourceTypes](docs/ResourceTypes.md)
 - [VoucherifySdk::Reward](docs/Reward.md)
 - [VoucherifySdk::RewardAssignment](docs/RewardAssignment.md)
 - [VoucherifySdk::RewardAssignmentParameters](docs/RewardAssignmentParameters.md)
 - [VoucherifySdk::RewardAssignmentParametersLoyalty](docs/RewardAssignmentParametersLoyalty.md)
 - [VoucherifySdk::RewardAttributes](docs/RewardAttributes.md)
 - [VoucherifySdk::RewardType](docs/RewardType.md)
 - [VoucherifySdk::RewardTypeCampaign](docs/RewardTypeCampaign.md)
 - [VoucherifySdk::RewardTypeCoin](docs/RewardTypeCoin.md)
 - [VoucherifySdk::RewardTypeProduct](docs/RewardTypeProduct.md)
 - [VoucherifySdk::RewardsAssignmentsCreateRequestBody](docs/RewardsAssignmentsCreateRequestBody.md)
 - [VoucherifySdk::RewardsAssignmentsCreateRequestBodyParameters](docs/RewardsAssignmentsCreateRequestBodyParameters.md)
 - [VoucherifySdk::RewardsAssignmentsCreateRequestBodyParametersLoyalty](docs/RewardsAssignmentsCreateRequestBodyParametersLoyalty.md)
 - [VoucherifySdk::RewardsAssignmentsCreateResponseBody](docs/RewardsAssignmentsCreateResponseBody.md)
 - [VoucherifySdk::RewardsAssignmentsCreateResponseBodyParameters](docs/RewardsAssignmentsCreateResponseBodyParameters.md)
 - [VoucherifySdk::RewardsAssignmentsCreateResponseBodyParametersLoyalty](docs/RewardsAssignmentsCreateResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::RewardsAssignmentsGetResponseBody](docs/RewardsAssignmentsGetResponseBody.md)
 - [VoucherifySdk::RewardsAssignmentsGetResponseBodyParameters](docs/RewardsAssignmentsGetResponseBodyParameters.md)
 - [VoucherifySdk::RewardsAssignmentsGetResponseBodyParametersLoyalty](docs/RewardsAssignmentsGetResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::RewardsAssignmentsListResponseBody](docs/RewardsAssignmentsListResponseBody.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateRequestBody](docs/RewardsAssignmentsUpdateRequestBody.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateRequestBodyParameters](docs/RewardsAssignmentsUpdateRequestBodyParameters.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateRequestBodyParametersLoyalty](docs/RewardsAssignmentsUpdateRequestBodyParametersLoyalty.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateResponseBody](docs/RewardsAssignmentsUpdateResponseBody.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateResponseBodyParameters](docs/RewardsAssignmentsUpdateResponseBodyParameters.md)
 - [VoucherifySdk::RewardsAssignmentsUpdateResponseBodyParametersLoyalty](docs/RewardsAssignmentsUpdateResponseBodyParametersLoyalty.md)
 - [VoucherifySdk::RewardsCreateRequestBody](docs/RewardsCreateRequestBody.md)
 - [VoucherifySdk::RewardsCreateRequestBodyAttributes](docs/RewardsCreateRequestBodyAttributes.md)
 - [VoucherifySdk::RewardsCreateRequestBodyParameters](docs/RewardsCreateRequestBodyParameters.md)
 - [VoucherifySdk::RewardsCreateRequestBodyParametersCampaign](docs/RewardsCreateRequestBodyParametersCampaign.md)
 - [VoucherifySdk::RewardsCreateRequestBodyParametersCoin](docs/RewardsCreateRequestBodyParametersCoin.md)
 - [VoucherifySdk::RewardsCreateRequestBodyParametersProduct](docs/RewardsCreateRequestBodyParametersProduct.md)
 - [VoucherifySdk::RewardsCreateResponseBody](docs/RewardsCreateResponseBody.md)
 - [VoucherifySdk::RewardsCreateResponseBodyAttributes](docs/RewardsCreateResponseBodyAttributes.md)
 - [VoucherifySdk::RewardsListResponseBody](docs/RewardsListResponseBody.md)
 - [VoucherifySdk::RewardsUpdateRequestBody](docs/RewardsUpdateRequestBody.md)
 - [VoucherifySdk::RewardsUpdateRequestBodyAttributes](docs/RewardsUpdateRequestBodyAttributes.md)
 - [VoucherifySdk::RewardsUpdateRequestBodyParameters](docs/RewardsUpdateRequestBodyParameters.md)
 - [VoucherifySdk::RewardsUpdateRequestBodyParametersCampaign](docs/RewardsUpdateRequestBodyParametersCampaign.md)
 - [VoucherifySdk::RewardsUpdateRequestBodyParametersCoin](docs/RewardsUpdateRequestBodyParametersCoin.md)
 - [VoucherifySdk::RewardsUpdateRequestBodyParametersProduct](docs/RewardsUpdateRequestBodyParametersProduct.md)
 - [VoucherifySdk::RewardsUpdateResponseBody](docs/RewardsUpdateResponseBody.md)
 - [VoucherifySdk::RewardsUpdateResponseBodyAttributes](docs/RewardsUpdateResponseBodyAttributes.md)
 - [VoucherifySdk::SegmentsCreateRequestBody](docs/SegmentsCreateRequestBody.md)
 - [VoucherifySdk::SegmentsCreateResponseBody](docs/SegmentsCreateResponseBody.md)
 - [VoucherifySdk::SegmentsGetResponseBody](docs/SegmentsGetResponseBody.md)
 - [VoucherifySdk::Session](docs/Session.md)
 - [VoucherifySdk::SimpleCustomer](docs/SimpleCustomer.md)
 - [VoucherifySdk::SimpleCustomerRequiredObjectType](docs/SimpleCustomerRequiredObjectType.md)
 - [VoucherifySdk::SimpleLoyaltyCard](docs/SimpleLoyaltyCard.md)
 - [VoucherifySdk::SimpleProductDiscountUnit](docs/SimpleProductDiscountUnit.md)
 - [VoucherifySdk::SimpleSegment](docs/SimpleSegment.md)
 - [VoucherifySdk::SimpleSkuDiscountUnit](docs/SimpleSkuDiscountUnit.md)
 - [VoucherifySdk::SimpleVoucher](docs/SimpleVoucher.md)
 - [VoucherifySdk::SimpleVoucherRedemption](docs/SimpleVoucherRedemption.md)
 - [VoucherifySdk::Sku](docs/Sku.md)
 - [VoucherifySdk::SkusGetResponseBody](docs/SkusGetResponseBody.md)
 - [VoucherifySdk::SkusImportCsvCreateResponseBody](docs/SkusImportCsvCreateResponseBody.md)
 - [VoucherifySdk::SkusListForProduct](docs/SkusListForProduct.md)
 - [VoucherifySdk::StackingRules](docs/StackingRules.md)
 - [VoucherifySdk::TemplatesCampaignsCampaignSetupCreateRequestBody](docs/TemplatesCampaignsCampaignSetupCreateRequestBody.md)
 - [VoucherifySdk::TemplatesCampaignsCampaignSetupCreateRequestBodyVoucher](docs/TemplatesCampaignsCampaignSetupCreateRequestBodyVoucher.md)
 - [VoucherifySdk::TemplatesCampaignsCampaignSetupCreateRequestBodyVoucherRedemption](docs/TemplatesCampaignsCampaignSetupCreateRequestBodyVoucherRedemption.md)
 - [VoucherifySdk::TemplatesCampaignsCampaignSetupCreateResponseBody](docs/TemplatesCampaignsCampaignSetupCreateResponseBody.md)
 - [VoucherifySdk::TemplatesCampaignsCampaignSetupCreateResponseBodyCreatedResourcesItem](docs/TemplatesCampaignsCampaignSetupCreateResponseBodyCreatedResourcesItem.md)
 - [VoucherifySdk::TemplatesCampaignsCreateRequestBody](docs/TemplatesCampaignsCreateRequestBody.md)
 - [VoucherifySdk::TemplatesCampaignsCreateTemplateResponseBody](docs/TemplatesCampaignsCreateTemplateResponseBody.md)
 - [VoucherifySdk::TemplatesCampaignsGetResponseBody](docs/TemplatesCampaignsGetResponseBody.md)
 - [VoucherifySdk::TemplatesCampaignsListResponseBody](docs/TemplatesCampaignsListResponseBody.md)
 - [VoucherifySdk::TemplatesCampaignsTierSetupCreateRequestBody](docs/TemplatesCampaignsTierSetupCreateRequestBody.md)
 - [VoucherifySdk::TemplatesCampaignsTierSetupCreateResponseBody](docs/TemplatesCampaignsTierSetupCreateResponseBody.md)
 - [VoucherifySdk::TemplatesCampaignsTierSetupCreateResponseBodyCreatedResourcesItem](docs/TemplatesCampaignsTierSetupCreateResponseBodyCreatedResourcesItem.md)
 - [VoucherifySdk::TemplatesCampaignsUpdateRequestBody](docs/TemplatesCampaignsUpdateRequestBody.md)
 - [VoucherifySdk::TemplatesCampaignsUpdateResponseBody](docs/TemplatesCampaignsUpdateResponseBody.md)
 - [VoucherifySdk::TrashBinItem](docs/TrashBinItem.md)
 - [VoucherifySdk::TrashBinListResponseBody](docs/TrashBinListResponseBody.md)
 - [VoucherifySdk::UsageNotifications](docs/UsageNotifications.md)
 - [VoucherifySdk::User](docs/User.md)
 - [VoucherifySdk::ValidationRule](docs/ValidationRule.md)
 - [VoucherifySdk::ValidationRuleApplicableTo](docs/ValidationRuleApplicableTo.md)
 - [VoucherifySdk::ValidationRuleAssignment](docs/ValidationRuleAssignment.md)
 - [VoucherifySdk::ValidationRuleAssignmentsList](docs/ValidationRuleAssignmentsList.md)
 - [VoucherifySdk::ValidationRuleError](docs/ValidationRuleError.md)
 - [VoucherifySdk::ValidationRulesAssignmentsCreateRequestBody](docs/ValidationRulesAssignmentsCreateRequestBody.md)
 - [VoucherifySdk::ValidationRulesAssignmentsCreateResponseBody](docs/ValidationRulesAssignmentsCreateResponseBody.md)
 - [VoucherifySdk::ValidationRulesAssignmentsList](docs/ValidationRulesAssignmentsList.md)
 - [VoucherifySdk::ValidationRulesAssignmentsListResponseBody](docs/ValidationRulesAssignmentsListResponseBody.md)
 - [VoucherifySdk::ValidationRulesCreateRequestBody](docs/ValidationRulesCreateRequestBody.md)
 - [VoucherifySdk::ValidationRulesCreateRequestBodyApplicableTo](docs/ValidationRulesCreateRequestBodyApplicableTo.md)
 - [VoucherifySdk::ValidationRulesCreateRequestBodyError](docs/ValidationRulesCreateRequestBodyError.md)
 - [VoucherifySdk::ValidationRulesCreateResponseBody](docs/ValidationRulesCreateResponseBody.md)
 - [VoucherifySdk::ValidationRulesCreateResponseBodyApplicableTo](docs/ValidationRulesCreateResponseBodyApplicableTo.md)
 - [VoucherifySdk::ValidationRulesCreateResponseBodyError](docs/ValidationRulesCreateResponseBodyError.md)
 - [VoucherifySdk::ValidationRulesGetResponseBody](docs/ValidationRulesGetResponseBody.md)
 - [VoucherifySdk::ValidationRulesGetResponseBodyApplicableTo](docs/ValidationRulesGetResponseBodyApplicableTo.md)
 - [VoucherifySdk::ValidationRulesGetResponseBodyError](docs/ValidationRulesGetResponseBodyError.md)
 - [VoucherifySdk::ValidationRulesListResponseBody](docs/ValidationRulesListResponseBody.md)
 - [VoucherifySdk::ValidationRulesUpdateRequestBody](docs/ValidationRulesUpdateRequestBody.md)
 - [VoucherifySdk::ValidationRulesUpdateRequestBodyApplicableTo](docs/ValidationRulesUpdateRequestBodyApplicableTo.md)
 - [VoucherifySdk::ValidationRulesUpdateRequestBodyError](docs/ValidationRulesUpdateRequestBodyError.md)
 - [VoucherifySdk::ValidationRulesUpdateResponseBody](docs/ValidationRulesUpdateResponseBody.md)
 - [VoucherifySdk::ValidationRulesUpdateResponseBodyApplicableTo](docs/ValidationRulesUpdateResponseBodyApplicableTo.md)
 - [VoucherifySdk::ValidationRulesUpdateResponseBodyError](docs/ValidationRulesUpdateResponseBodyError.md)
 - [VoucherifySdk::ValidationsRedeemableInapplicable](docs/ValidationsRedeemableInapplicable.md)
 - [VoucherifySdk::ValidationsRedeemableInapplicableResult](docs/ValidationsRedeemableInapplicableResult.md)
 - [VoucherifySdk::ValidationsRedeemableInapplicableResultDetails](docs/ValidationsRedeemableInapplicableResultDetails.md)
 - [VoucherifySdk::ValidationsRedeemableSkipped](docs/ValidationsRedeemableSkipped.md)
 - [VoucherifySdk::ValidationsRedeemableSkippedResult](docs/ValidationsRedeemableSkippedResult.md)
 - [VoucherifySdk::ValidationsRedeemableSkippedResultDetails](docs/ValidationsRedeemableSkippedResultDetails.md)
 - [VoucherifySdk::ValidationsValidateRequestBody](docs/ValidationsValidateRequestBody.md)
 - [VoucherifySdk::ValidationsValidateRequestBodyOptions](docs/ValidationsValidateRequestBodyOptions.md)
 - [VoucherifySdk::ValidationsValidateRequestBodyRedeemablesItem](docs/ValidationsValidateRequestBodyRedeemablesItem.md)
 - [VoucherifySdk::ValidationsValidateRequestBodyRedeemablesItemGift](docs/ValidationsValidateRequestBodyRedeemablesItemGift.md)
 - [VoucherifySdk::ValidationsValidateRequestBodyRedeemablesItemReward](docs/ValidationsValidateRequestBodyRedeemablesItemReward.md)
 - [VoucherifySdk::ValidationsValidateResponseBody](docs/ValidationsValidateResponseBody.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItem](docs/ValidationsValidateResponseBodyRedeemablesItem.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResult](docs/ValidationsValidateResponseBodyRedeemablesItemResult.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResultDetails](docs/ValidationsValidateResponseBodyRedeemablesItemResultDetails.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResultDiscount](docs/ValidationsValidateResponseBodyRedeemablesItemResultDiscount.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct](docs/ValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResultGift](docs/ValidationsValidateResponseBodyRedeemablesItemResultGift.md)
 - [VoucherifySdk::ValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard](docs/ValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard.md)
 - [VoucherifySdk::ValidityHours](docs/ValidityHours.md)
 - [VoucherifySdk::ValidityHoursDailyItem](docs/ValidityHoursDailyItem.md)
 - [VoucherifySdk::ValidityTimeframe](docs/ValidityTimeframe.md)
 - [VoucherifySdk::Voucher](docs/Voucher.md)
 - [VoucherifySdk::VoucherAssets](docs/VoucherAssets.md)
 - [VoucherifySdk::VoucherAssetsBarcode](docs/VoucherAssetsBarcode.md)
 - [VoucherifySdk::VoucherAssetsQr](docs/VoucherAssetsQr.md)
 - [VoucherifySdk::VoucherGift](docs/VoucherGift.md)
 - [VoucherifySdk::VoucherLoyaltyCard](docs/VoucherLoyaltyCard.md)
 - [VoucherifySdk::VoucherPublish](docs/VoucherPublish.md)
 - [VoucherifySdk::VoucherRedemption](docs/VoucherRedemption.md)
 - [VoucherifySdk::VoucherTransaction](docs/VoucherTransaction.md)
 - [VoucherifySdk::VoucherTransactionDetails](docs/VoucherTransactionDetails.md)
 - [VoucherifySdk::VoucherTransactionDetailsBalance](docs/VoucherTransactionDetailsBalance.md)
 - [VoucherifySdk::VoucherTransactionDetailsBalanceRelatedObject](docs/VoucherTransactionDetailsBalanceRelatedObject.md)
 - [VoucherifySdk::VoucherTransactionDetailsCustomEvent](docs/VoucherTransactionDetailsCustomEvent.md)
 - [VoucherifySdk::VoucherTransactionDetailsEarningRule](docs/VoucherTransactionDetailsEarningRule.md)
 - [VoucherifySdk::VoucherTransactionDetailsEarningRuleSource](docs/VoucherTransactionDetailsEarningRuleSource.md)
 - [VoucherifySdk::VoucherTransactionDetailsEvent](docs/VoucherTransactionDetailsEvent.md)
 - [VoucherifySdk::VoucherTransactionDetailsEventSchema](docs/VoucherTransactionDetailsEventSchema.md)
 - [VoucherifySdk::VoucherTransactionDetailsLoyaltyTier](docs/VoucherTransactionDetailsLoyaltyTier.md)
 - [VoucherifySdk::VoucherTransactionDetailsOrder](docs/VoucherTransactionDetailsOrder.md)
 - [VoucherifySdk::VoucherTransactionDetailsRedemption](docs/VoucherTransactionDetailsRedemption.md)
 - [VoucherifySdk::VoucherTransactionDetailsReward](docs/VoucherTransactionDetailsReward.md)
 - [VoucherifySdk::VoucherTransactionDetailsRollback](docs/VoucherTransactionDetailsRollback.md)
 - [VoucherifySdk::VoucherTransactionDetailsSegment](docs/VoucherTransactionDetailsSegment.md)
 - [VoucherifySdk::VoucherTransactionsExportFilterConditions](docs/VoucherTransactionsExportFilterConditions.md)
 - [VoucherifySdk::VoucherTransactionsExportFilterConditionsVoucherId](docs/VoucherTransactionsExportFilterConditionsVoucherId.md)
 - [VoucherifySdk::VoucherTransactionsExportFilterConditionsVoucherIdConditions](docs/VoucherTransactionsExportFilterConditionsVoucherIdConditions.md)
 - [VoucherifySdk::VoucherTransactionsExportParameters](docs/VoucherTransactionsExportParameters.md)
 - [VoucherifySdk::VoucherTransactionsFilters](docs/VoucherTransactionsFilters.md)
 - [VoucherifySdk::VoucherWithCategories](docs/VoucherWithCategories.md)
 - [VoucherifySdk::VoucherWithCategoriesGift](docs/VoucherWithCategoriesGift.md)
 - [VoucherifySdk::VoucherWithCategoriesLoyaltyCard](docs/VoucherWithCategoriesLoyaltyCard.md)
 - [VoucherifySdk::VoucherWithCategoriesPublish](docs/VoucherWithCategoriesPublish.md)
 - [VoucherifySdk::VoucherWithCategoriesRedemption](docs/VoucherWithCategoriesRedemption.md)
 - [VoucherifySdk::VouchersBalanceUpdateRequestBody](docs/VouchersBalanceUpdateRequestBody.md)
 - [VoucherifySdk::VouchersBalanceUpdateResponseBody](docs/VouchersBalanceUpdateResponseBody.md)
 - [VoucherifySdk::VouchersBalanceUpdateResponseBodyRelatedObject](docs/VouchersBalanceUpdateResponseBodyRelatedObject.md)
 - [VoucherifySdk::VouchersCreateRequestBody](docs/VouchersCreateRequestBody.md)
 - [VoucherifySdk::VouchersCreateRequestBodyRedemption](docs/VouchersCreateRequestBodyRedemption.md)
 - [VoucherifySdk::VouchersCreateResponseBody](docs/VouchersCreateResponseBody.md)
 - [VoucherifySdk::VouchersCreateResponseBodyGift](docs/VouchersCreateResponseBodyGift.md)
 - [VoucherifySdk::VouchersCreateResponseBodyLoyaltyCard](docs/VouchersCreateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::VouchersCreateResponseBodyPublish](docs/VouchersCreateResponseBodyPublish.md)
 - [VoucherifySdk::VouchersCreateResponseBodyRedemption](docs/VouchersCreateResponseBodyRedemption.md)
 - [VoucherifySdk::VouchersCreateWithSpecificCodeRequestBody](docs/VouchersCreateWithSpecificCodeRequestBody.md)
 - [VoucherifySdk::VouchersCreateWithSpecificCodeRequestBodyRedemption](docs/VouchersCreateWithSpecificCodeRequestBodyRedemption.md)
 - [VoucherifySdk::VouchersDisableResponseBody](docs/VouchersDisableResponseBody.md)
 - [VoucherifySdk::VouchersDisableResponseBodyGift](docs/VouchersDisableResponseBodyGift.md)
 - [VoucherifySdk::VouchersDisableResponseBodyLoyaltyCard](docs/VouchersDisableResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::VouchersDisableResponseBodyPublish](docs/VouchersDisableResponseBodyPublish.md)
 - [VoucherifySdk::VouchersDisableResponseBodyRedemption](docs/VouchersDisableResponseBodyRedemption.md)
 - [VoucherifySdk::VouchersEnableResponseBody](docs/VouchersEnableResponseBody.md)
 - [VoucherifySdk::VouchersEnableResponseBodyGift](docs/VouchersEnableResponseBodyGift.md)
 - [VoucherifySdk::VouchersEnableResponseBodyLoyaltyCard](docs/VouchersEnableResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::VouchersEnableResponseBodyPublish](docs/VouchersEnableResponseBodyPublish.md)
 - [VoucherifySdk::VouchersEnableResponseBodyRedemption](docs/VouchersEnableResponseBodyRedemption.md)
 - [VoucherifySdk::VouchersGetResponseBody](docs/VouchersGetResponseBody.md)
 - [VoucherifySdk::VouchersGetResponseBodyGift](docs/VouchersGetResponseBodyGift.md)
 - [VoucherifySdk::VouchersGetResponseBodyLoyaltyCard](docs/VouchersGetResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::VouchersGetResponseBodyPublish](docs/VouchersGetResponseBodyPublish.md)
 - [VoucherifySdk::VouchersGetResponseBodyRedemption](docs/VouchersGetResponseBodyRedemption.md)
 - [VoucherifySdk::VouchersImportCreateItemRequestBody](docs/VouchersImportCreateItemRequestBody.md)
 - [VoucherifySdk::VouchersImportCreateItemRequestBodyRedemption](docs/VouchersImportCreateItemRequestBodyRedemption.md)
 - [VoucherifySdk::VouchersImportCreateResponseBody](docs/VouchersImportCreateResponseBody.md)
 - [VoucherifySdk::VouchersImportCsvCreateResponseBody](docs/VouchersImportCsvCreateResponseBody.md)
 - [VoucherifySdk::VouchersListResponseBody](docs/VouchersListResponseBody.md)
 - [VoucherifySdk::VouchersMetadataUpdateInBulkRequestBody](docs/VouchersMetadataUpdateInBulkRequestBody.md)
 - [VoucherifySdk::VouchersMetadataUpdateInBulkResponseBody](docs/VouchersMetadataUpdateInBulkResponseBody.md)
 - [VoucherifySdk::VouchersRedemptionGetResponseBody](docs/VouchersRedemptionGetResponseBody.md)
 - [VoucherifySdk::VouchersTransactionsExportCreateRequestBody](docs/VouchersTransactionsExportCreateRequestBody.md)
 - [VoucherifySdk::VouchersTransactionsExportCreateResponseBody](docs/VouchersTransactionsExportCreateResponseBody.md)
 - [VoucherifySdk::VouchersTransactionsExportCreateResponseBodyResult](docs/VouchersTransactionsExportCreateResponseBodyResult.md)
 - [VoucherifySdk::VouchersTransactionsListResponseBody](docs/VouchersTransactionsListResponseBody.md)
 - [VoucherifySdk::VouchersUpdateInBulkItemRequestBody](docs/VouchersUpdateInBulkItemRequestBody.md)
 - [VoucherifySdk::VouchersUpdateInBulkResponseBody](docs/VouchersUpdateInBulkResponseBody.md)
 - [VoucherifySdk::VouchersUpdateRequestBody](docs/VouchersUpdateRequestBody.md)
 - [VoucherifySdk::VouchersUpdateResponseBody](docs/VouchersUpdateResponseBody.md)
 - [VoucherifySdk::VouchersUpdateResponseBodyGift](docs/VouchersUpdateResponseBodyGift.md)
 - [VoucherifySdk::VouchersUpdateResponseBodyLoyaltyCard](docs/VouchersUpdateResponseBodyLoyaltyCard.md)
 - [VoucherifySdk::VouchersUpdateResponseBodyPublish](docs/VouchersUpdateResponseBodyPublish.md)
 - [VoucherifySdk::VouchersUpdateResponseBodyRedemption](docs/VouchersUpdateResponseBodyRedemption.md)

